@@ -93,6 +93,15 @@ nearest_power_of_two(const uint32_t value)
   return rc;
 }
 
+static void
+dt_cache_sleep_ms(uint32_t ms)
+{
+  struct timeval s;
+  s.tv_sec = ms / 1000;
+  s.tv_usec = (ms % 1000) * 1000U;
+  select(0, NULL, NULL, NULL, &s);
+}
+
 #if 0
 static uint32_t
 calc_div_shift(const uint32_t value)
@@ -328,9 +337,11 @@ void
 dt_cache_init(dt_cache_t *cache, const int32_t capacity, const int32_t num_threads, int32_t cache_line_size, int32_t cost_quota)
 {
   const uint32_t adj_num_threads = nearest_power_of_two(num_threads);
-  cache->cache_mask = cache_line_size / sizeof(dt_cache_bucket_t) - 1;
   // FIXME: if switching this on, lru lists need to move, too! (because they work by bucket and not by key)
   cache->optimize_cacheline = 0;//1;
+  // No cache_mask offsetting required when not optimizing for cachelines --RAM
+  cache->cache_mask = cache->optimize_cacheline ?
+    cache_line_size / sizeof(dt_cache_bucket_t) - 1 : 0;
   cache->segment_mask = adj_num_threads - 1;
   // cache->segment_shift = calc_div_shift(nearest_power_of_two(num_threads/(float)adj_num_threads)-1);
   // we want a minimum of four entries, as the hopscotch code below proceeds by disregarding the first bucket in the list,
@@ -641,6 +652,8 @@ dt_cache_read_get(
     dt_cache_t     *cache,
     const uint32_t  key)
 {
+  assert(key != DT_CACHE_EMPTY_KEY);
+
   // this is the blocking variant, we might need to allocate stuff.
   // also we have to retry if failed.
 
@@ -685,11 +698,7 @@ dt_cache_read_get(
     break;
 wait:;
     // try again in 5 milliseconds
-    struct timeval s;
-    s.tv_sec = 0;
-    s.tv_usec = 5000;
-    select(0, NULL, NULL, NULL, &s);
-    sched_yield();
+    dt_cache_sleep_ms(5);
   }
 
   if(cache->optimize_cacheline)
@@ -1042,11 +1051,7 @@ dt_cache_write_get(dt_cache_t *cache, const uint32_t key)
     break;
 wait:;
     // try again in 5 milliseconds
-    struct timeval s;
-    s.tv_sec = 0;
-    s.tv_usec = 5000;
-    select(0, NULL, NULL, NULL, &s);
-    sched_yield();
+    dt_cache_sleep_ms(5);
   }
   dt_cache_unlock(&segment->lock);
   // clear user error, he should hold a read lock already, so this has to be there.
