@@ -1,6 +1,7 @@
 #ifndef DT_COMMON_COLORLABELS_H
 #define DT_COMMON_COLORLABELS_H
 
+#include "common/darktable.h"
 #include <gtk/gtk.h>
 
 /** remove assigned colorlabels of selected images*/
@@ -18,7 +19,7 @@ void dt_colorlabels_remove_label (const int imgid, const int color);
 /** get the name of the color for a given number (could be replaced by an array) */
 const char* dt_colorlabels_to_string(int label);
 
-void dt_colorlabels_key_accel_callback(GtkAccelGroup *accel_group,
+gboolean dt_colorlabels_key_accel_callback(GtkAccelGroup *accel_group,
                                        GObject *acceleratable, guint keyval,
                                        GdkModifierType modifier, gpointer data);
 
