@@ -49,6 +49,9 @@ static dt_profiled_colormatrix_t dt_profiled_colormatrices[] =
   // Xavier Besse, CMP Digital Target 3, direct sunlight, well lit
   { "Canon EOS 5D Mark II",         { 967590, 399139,  36026}, { -52094,  819046, -232071}, {144455, -143158, 1069305}, {864227, 899139, 741547}},
 
+  // Russell Harrison, Wolf Faust IT8, direct sunlight, well lit
+  { "Canon EOS 5D Mark III",        { 947891, 312958,  -7126}, { 163071, 1301834, -276596}, { 75928, -363388, 1272232}, {741272, 757050, 662430}},
+
   // Deacon MacMillan, Kodak Q60 (IT8), strobe, well lit
   { "Canon EOS 5D",                 { 971420, 386429,   5753}, { 176849, 1141586, -137955}, { 81909, -284790, 1198090}, {753662, 783997, 645142}},
 
@@ -132,6 +135,9 @@ static dt_profiled_colormatrix_t dt_profiled_colormatrices[] =
   // Robert Park, ColorChecker Passport, strobe, well lit
   { "NIKON D5000",                  { 852386, 356232,  42389}, { 205353, 1026688, -220184}, {  6348, -292526, 1083313}, {822647, 849106, 688538}},
 
+  // Isaac Chanin, Wolf Faust IT8, direct sunlight, well lit
+  { "NIKON D5100",                  { 994339, 388123,  37186}, { 226578, 1268478, -310028}, {  1404, -393173, 1285812}, {705582, 733917, 623779}},
+
   // Robert Park, ColorChecker Passport, strobe, well lit
   { "NIKON D7000",                  { 744919, 228027, -46982}, { 454605, 1326797,  -33585}, {-132294, -467194, 985611}, {609375, 629852, 515625}},
 
@@ -147,6 +153,9 @@ static dt_profiled_colormatrix_t dt_profiled_colormatrices[] =
   // Robert Park, ColorChecker Passport, strobe, well lit
   { "NIKON D700",                   { 789261, 332016,  34149}, { 270386,  985748, -129135}, {  4074, -230209,  999008}, {798172, 826721, 673126}},
 
+  // Mauro Fuentes, ColorChecker Passport, direct sunlight, well lit
+  { "NIKON D800",                   { 792038, 268860,  33951}, { 289093, 1169876, -251740}, {-32654, -340393, 1127960}, {782806, 804443, 659058}},
+
   // Robert Park, ColorChecker Passport, strobe, well lit
   { "NIKON COOLPIX P7000",          { 804947, 229630,  97717}, { 178146, 1138763, -395233}, { 88699, -282013, 1234650}, {809998, 842819, 682144}},
 
@@ -227,3 +236,42 @@ static dt_profiled_colormatrix_t dt_profiled_colormatrices[] =
 
 static const int dt_profiled_colormatrix_cnt = sizeof(dt_profiled_colormatrices)/sizeof(dt_profiled_colormatrix_t);
 
+static dt_profiled_colormatrix_t dt_vendor_colormatrices[] =
+{
+  // Pascal de Bruijn, DIY ColorChecker, daylight, well lit
+  { "Canon EOS 50D",                { 665588, 259155, -37750}, {  61172,  790497, -117310}, {237442,  -49667,  979965}, {946487, 1000000, 1082657}},
+
+  // Pascal de Bruijn, ColorChecker Classic, daylight, well lit
+  { "Canon EOS 400D DIGITAL",       { 561768, 248581,  21408}, { 211548,  774429,  -57526}, {190887,  -22995,  861008}, {961594, 1000000, 1086395}},
+  { "Canon EOS DIGITAL REBEL XTi",  { 561768, 248581,  21408}, { 211548,  774429,  -57526}, {190887,  -22995,  861008}, {961594, 1000000, 1086395}},
+  { "Canon EOS Kiss Digital X",     { 561768, 248581,  21408}, { 211548,  774429,  -57526}, {190887,  -22995,  861008}, {961594, 1000000, 1086395}},
+
+  // Pascal de Bruijn, ColorChecker Classic, daylight, well lit
+  { "SAMSUNG NX100",                { 590607, 279297,  29831}, { 245789,  745789,  -84747}, {127808,  -25101,  879822}, {955185, 1000000, 1089981}},
+
+  // Copied from NX100
+  { "SAMSUNG NX5",                  { 590607, 279297,  29831}, { 245789,  745789,  -84747}, {127808,  -25101,  879822}, {955185, 1000000, 1089981}},
+  { "SAMSUNG NX10",                 { 590607, 279297,  29831}, { 245789,  745789,  -84747}, {127808,  -25101,  879822}, {955185, 1000000, 1089981}},
+  { "SAMSUNG NX111",                { 590607, 279297,  29831}, { 245789,  745789,  -84747}, {127808,  -25101,  879822}, {955185, 1000000, 1089981}},
+};
+
+static const int dt_vendor_colormatrix_cnt = sizeof(dt_vendor_colormatrices)/sizeof(dt_profiled_colormatrix_t);
+
+static dt_profiled_colormatrix_t dt_alternate_colormatrices[] =
+{
+  // Pascal de Bruijn, ColorChecker Classic, daylight, well lit
+  { "Canon EOS 400D DIGITAL",       { 773514, 302612,  25558}, { 244278, 1107727, -177689}, { 55725, -289902, 1080765}, {822388, 847488, 696823}},
+  { "Canon EOS DIGITAL REBEL XTi",  { 773514, 302612,  25558}, { 244278, 1107727, -177689}, { 55725, -289902, 1080765}, {822388, 847488, 696823}},
+  { "Canon EOS Kiss Digital X",     { 773514, 302612,  25558}, { 244278, 1107727, -177689}, { 55725, -289902, 1080765}, {822388, 847488, 696823}},
+
+  // Pascal de Bruijn, ColorChecker Classic, daylight, well lit
+  { "SAMSUNG NX100",                { 773254, 310013,  12573}, { 299774, 1003143, -150620}, {  4715, -192886, 1070877}, {817657, 850372, 693924}},
+
+  // Copied from NX100
+  { "SAMSUNG NX5",                  { 773254, 310013,  12573}, { 299774, 1003143, -150620}, {  4715, -192886, 1070877}, {817657, 850372, 693924}},
+  { "SAMSUNG NX10",                 { 773254, 310013,  12573}, { 299774, 1003143, -150620}, {  4715, -192886, 1070877}, {817657, 850372, 693924}},
+  { "SAMSUNG NX111",                { 773254, 310013,  12573}, { 299774, 1003143, -150620}, {  4715, -192886, 1070877}, {817657, 850372, 693924}},
+};
+
+static const int dt_alternate_colormatrix_cnt = sizeof(dt_alternate_colormatrices)/sizeof(dt_profiled_colormatrix_t);
+
