@@ -85,8 +85,9 @@ typedef void (dt_signal_handler_t)(int) ;
 // static dt_signal_handler_t *_dt_sigill_old_handler = NULL;
 static dt_signal_handler_t *_dt_sigsegv_old_handler = NULL;
 
-#if defined(__APPLE__) || (defined(__FreeBSD_version) && __FreeBSD_version < 800071) || \
-    defined(__SUNOS__)
+#if (defined(__APPLE__) && defined(APPLE_NEED_DPRINTF)) ||        \
+  (defined(__FreeBSD_version) && (__FreeBSD_version < 800071)) || \
+  defined(__SUNOS__)
 static int dprintf(int fd,const char *fmt, ...)
 {
   va_list ap;
