@@ -50,7 +50,8 @@ dt_imageio_export_with_flags(
     struct dt_imageio_module_data_t   *format_params,
     const int32_t                      ignore_exif,
     const int32_t                      display_byteorder,
-    const int32_t                      high_quality);
+    const int32_t                      high_quality,
+    const int32_t                      thumbnail_export);
 
 int dt_imageio_write_pos(int i, int j, int wd, int ht, float fwd, float fht, int orientation);
 
