@@ -19,8 +19,8 @@
 #define DT_IMAGEIO_TIFF_H
 
 #include "common/image.h"
+#include "common/mipmap_cache.h"
 
-dt_imageio_retval_t dt_imageio_open_tiff(dt_image_t *img, const char *filename);
-dt_imageio_retval_t dt_imageio_open_tiff_preview(dt_image_t *img, const char *filename);
+dt_imageio_retval_t dt_imageio_open_tiff(dt_image_t *img, const char *filename, dt_mipmap_cache_allocator_t a);
 
 #endif
