@@ -18,15 +18,15 @@
 
 #ifdef HAVE_OPENCL
 
-#include <string.h>
-#include <stdio.h>
-#include <assert.h>
-
 #include "common/darktable.h"
 #include "common/opencl.h"
 #include "common/dlopencl.h"
 #include "control/conf.h"
 
+#include <string.h>
+#include <stdio.h>
+#include <assert.h>
+
 #define max(a,b) ((a) > (b) ? (a) : (b))
 
 void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
@@ -55,7 +55,7 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
       exclude_opencl = 1;
     }
 
-  if(exclude_opencl) return;
+  if(exclude_opencl) goto finally;
 
 
   // look for explicit definition of opencl_runtime library in preferences
@@ -66,7 +66,7 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
   if(!dt_dlopencl_init(library, &cl->dlocl))
     {
       dt_print(DT_DEBUG_OPENCL, "[opencl_init] no working opencl library found. Continue with opencl disabled\n");
-      return;
+      goto finally;
     }
     else
     {
@@ -81,7 +81,7 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
   if(err != CL_SUCCESS)
   {
     dt_print(DT_DEBUG_OPENCL, "[opencl_init] could not get platforms: %d\n", err);
-    return;
+    goto finally;
   }
   platform = all_platforms[0];
 
@@ -92,7 +92,7 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
   if(err != CL_SUCCESS)
   {
     dt_print(DT_DEBUG_OPENCL, "[opencl_init] could not get device id size: %d\n", err);
-    return;
+    goto finally;
   }
 
   // create the device list
@@ -102,7 +102,7 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
   if(err != CL_SUCCESS)
   {
     dt_print(DT_DEBUG_OPENCL, "[opencl_init] could not get devices list: %d\n", err);
-    return;
+    goto finally;
   }
   dt_print(DT_DEBUG_OPENCL, "[opencl_init] found %d devices\n", num_devices);
   int dev = 0;
@@ -123,14 +123,23 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
     char infostr[1024];
     size_t infoint;
     size_t infointtab[1024];
+    cl_device_type type;
     cl_bool image_support = 0;
 
     // test GPU memory and image support:
     (cl->dlocl->symbols->dt_clGetDeviceInfo)(devid, CL_DEVICE_NAME, sizeof(infostr), &infostr, NULL);
+    (cl->dlocl->symbols->dt_clGetDeviceInfo)(devid, CL_DEVICE_TYPE, sizeof(cl_device_type), &type,  NULL);
     (cl->dlocl->symbols->dt_clGetDeviceInfo)(devid, CL_DEVICE_IMAGE_SUPPORT, sizeof(cl_bool), &image_support, NULL);
     (cl->dlocl->symbols->dt_clGetDeviceInfo)(devid, CL_DEVICE_IMAGE2D_MAX_HEIGHT, sizeof(size_t), &(cl->dev[dev].max_image_height), NULL);
     (cl->dlocl->symbols->dt_clGetDeviceInfo)(devid, CL_DEVICE_IMAGE2D_MAX_WIDTH,  sizeof(size_t), &(cl->dev[dev].max_image_width),  NULL);
     (cl->dlocl->symbols->dt_clGetDeviceInfo)(devid, CL_DEVICE_MAX_MEM_ALLOC_SIZE,  sizeof(cl_ulong), &(cl->dev[dev].max_mem_alloc),  NULL);
+
+    if(type == CL_DEVICE_TYPE_CPU)
+    {
+      dt_print(DT_DEBUG_OPENCL, "[opencl_init] discarding CPU device %d `%s' as it will not deliver any performance gain.\n", k, infostr);
+      continue;
+    }
+
     if(!image_support)
     {
       dt_print(DT_DEBUG_OPENCL, "[opencl_init] discarding device %d `%s' due to missing image support.\n", k, infostr);
@@ -165,14 +174,14 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
     if(err != CL_SUCCESS)
     {
       dt_print(DT_DEBUG_OPENCL, "[opencl_init] could not create context for device %d: %d\n", k, err);
-      return;
+      goto finally;
     }
     // create a command queue for first device the context reported
     cl->dev[dev].cmd_queue = (cl->dlocl->symbols->dt_clCreateCommandQueue)(cl->dev[dev].context, devid, (darktable.unmuted & DT_DEBUG_PERF) ? CL_QUEUE_PROFILING_ENABLE : 0, &err);
     if(err != CL_SUCCESS)
     {
       dt_print(DT_DEBUG_OPENCL, "[opencl_init] could not create command queue for device %d: %d\n", k, err);
-      return;
+      goto finally;
     }
     char dtpath[1024], filename[1024], programname[1024];
     dt_util_get_datadir(dtpath, 1024);
@@ -187,10 +196,17 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
         int rd = fscanf(f, "%[^\n]\n", programname);
         if(rd != 1) continue;
         // remove comments:
-        for(int k=0; k<strlen(programname); k++) if(programname[k] == '#')
+        for(int k=0; k<strlen(programname); k++)
+          if(programname[k] == '#')
           {
             programname[k] = '\0';
-            while(programname[--k] == ' ') programname[k] = '\0';
+            for(int l=k-1; l>=0; l--)
+            {   
+              if (programname[l] == ' ')
+	        programname[l] = '\0';
+              else
+	        break;
+            }
             break;
           }
         if(programname[0] == '\0') continue;
@@ -200,7 +216,7 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
         if(dt_opencl_build_program(k, prog))
         {
           dt_print(DT_DEBUG_OPENCL, "[opencl_init] failed to compile program `%s'!\n", programname);
-          return;
+          goto finally;
         }
       }
       fclose(f);
@@ -208,7 +224,7 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
     else
     {
       dt_print(DT_DEBUG_OPENCL, "[opencl_init] could not open `%s'!\n", filename);
-      return;
+      goto finally;
     }
     ++dev;
   }
@@ -216,7 +232,6 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
   if(dev > 0)
   {
     dt_print(DT_DEBUG_OPENCL, "[opencl_init] successfully initialized.\n");
-    dt_print(DT_DEBUG_OPENCL, "[opencl_init] initial status of opencl enabled flag is %s.\n", prefs ? "ON" : "OFF");
     cl->num_devs = dev;
     cl->inited = 1;
     cl->enabled = prefs;
@@ -227,6 +242,10 @@ void dt_opencl_init(dt_opencl_t *cl, const int argc, char *argv[])
   {
     dt_print(DT_DEBUG_OPENCL, "[opencl_init] no suitable devices found.\n");
   }
+
+finally:
+  dt_print(DT_DEBUG_OPENCL, "[opencl_init] FINALLY: opencl is %sAVAILABLE on this system.\n", cl->inited ? "" : "NOT ");
+  dt_print(DT_DEBUG_OPENCL, "[opencl_init] initial status of opencl enabled flag is %s.\n", cl->enabled ? "ON" : "OFF");
   return;
 }
 
