@@ -440,15 +440,8 @@ void dt_control_remove_images()
   {
     GtkWidget *dialog;
     GtkWidget *win = dt_ui_main_window(darktable.gui->ui);
-    
-    sqlite3_stmt *stmt = NULL;
-    int number = 0;
-    
-    DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "select count(imgid) from selected_images", -1, &stmt, NULL);
-    if(sqlite3_step(stmt) == SQLITE_ROW)
-    {
-      number = sqlite3_column_int(stmt, 0);
-    }
+
+    int number = dt_collection_get_selected_count(darktable.collection);
 
     dialog = gtk_message_dialog_new(GTK_WINDOW(win),
                                     GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -456,6 +449,7 @@ void dt_control_remove_images()
                                     GTK_BUTTONS_YES_NO,
                                     ngettext("do you really want to remove %d selected image from the collection?", 
                                              "do you really want to remove %d selected images from the collection?", number), number);
+
     gtk_window_set_title(GTK_WINDOW(dialog), _("remove images?"));
     gint res = gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy(dialog);
@@ -473,14 +467,7 @@ void dt_control_delete_images()
     GtkWidget *dialog;
     GtkWidget *win = dt_ui_main_window(darktable.gui->ui);
 
-    sqlite3_stmt *stmt = NULL;
-    int number = 0;
-    
-    DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "select count(imgid) from selected_images", -1, &stmt, NULL);
-    if(sqlite3_step(stmt) == SQLITE_ROW)
-    {
-      number = sqlite3_column_int(stmt, 0);
-    }
+    int number = dt_collection_get_selected_count(darktable.collection);
 
     dialog = gtk_message_dialog_new(GTK_WINDOW(win),
                                     GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -488,6 +475,7 @@ void dt_control_delete_images()
                                     GTK_BUTTONS_YES_NO,
                                     ngettext("do you really want to physically delete %d selected image from disk?",
                                              "do you really want to physically delete %d selected images from disk?", number), number);
+
     gtk_window_set_title(GTK_WINDOW(dialog), _("delete images?"));
     gint res = gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy(dialog);
