@@ -1,6 +1,7 @@
 /*
     This file is part of darktable,
     copyright (c) 2009--2011 johannes hanika.
+    copyright (c) 2011 henrik andersson.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +23,7 @@
 #include "control/control.h"
 #include "control/conf.h"
 #include "common/image_cache.h"
+#include "common/mipmap_cache.h"
 #include "common/imageio.h"
 #include "common/tags.h"
 #include "common/debug.h"
@@ -36,39 +38,10 @@
 #include <assert.h>
 
 
-uint8_t dt_dev_default_gamma[0x10000];
-float dt_dev_de_gamma[0x100];
-
-void dt_dev_set_gamma_array(dt_develop_t *dev, const float linear, const float gamma, uint8_t *arr)
-{
-  double a, b, c, g;
-  if(linear<1.0)
-  {
-    g = gamma*(1.0-linear)/(1.0-gamma*linear);
-    a = 1.0/(1.0+linear*(g-1));
-    b = linear*(g-1)*a;
-    c = pow(a*linear+b, g)/linear;
-  }
-  else
-  {
-    a = b = g = 0.0;
-    c = 1.0;
-  }
-
-  for(int k=0; k<0x10000; k++)
-  {
-    // int32_t tmp = 0x10000 * powf(k/(float)0x10000, 1./2.2);
-    int32_t tmp;
-    if (k<0x10000*linear) tmp = MIN(c*k, 0xFFFF);
-    else tmp = MIN(pow(a*k/0x10000+b, g)*0x10000, 0xFFFF);
-    arr[k] = tmp>>8;
-  }
-}
-
 void dt_dev_init(dt_develop_t *dev, int32_t gui_attached)
 {
-  float downsampling = dt_conf_get_float ("preview_subsample");
-  dev->preview_downsampling = downsampling <= 1.0 && downsampling >= 0.1 ? downsampling : .5;
+  memset(dev,0,sizeof(dt_develop_t));
+  dev->preview_downsampling = 1.0f;
   dev->gui_module = NULL;
   dev->timestamp = 0;
   dev->gui_leaving = 0;
@@ -80,16 +53,17 @@ void dt_dev_init(dt_develop_t *dev, int32_t gui_attached)
   dev->gui_attached = gui_attached;
   dev->width = -1;
   dev->height = -1;
-  dev->mipf = NULL;
 
-  dev->image = NULL;
+  dt_image_init(&dev->image_storage);
   dev->image_dirty = dev->preview_dirty = 1;
   dev->image_loading = dev->preview_loading = 0;
   dev->image_force_reload = 0;
   dev->preview_input_changed = 0;
 
   dev->pipe = dev->preview_pipe = NULL;
-  dev->histogram = dev->histogram_pre = NULL;
+  dev->histogram = NULL;
+  dev->histogram_pre_tonecurve = NULL;
+  dev->histogram_pre_levels = NULL;
 
   if(dev->gui_attached)
   {
@@ -99,43 +73,15 @@ void dt_dev_init(dt_develop_t *dev, int32_t gui_attached)
     dt_dev_pixelpipe_init(dev->preview_pipe);
 
     dev->histogram = (float *)malloc(sizeof(float)*4*256);
-    dev->histogram_pre = (float *)malloc(sizeof(float)*4*256);
+    dev->histogram_pre_tonecurve = (float *)malloc(sizeof(float)*4*256);
+    dev->histogram_pre_levels = (float*)malloc(sizeof(float) * 4 * 256);
     memset(dev->histogram, 0, sizeof(float)*256*4);
-    memset(dev->histogram_pre, 0, sizeof(float)*256*4);
+    memset(dev->histogram_pre_tonecurve, 0, sizeof(float)*256*4);
+    memset(dev->histogram_pre_levels, 0, sizeof(float)*256*4);
     dev->histogram_max = -1;
-    dev->histogram_pre_max = -1;
-
-#if 0 // this prints out a correction curve, to better understand the tonecurve.
-    dt_dev_set_gamma_array(dev, 0.04045, 0.41, dt_dev_default_gamma);
-    int last1 = 0; // invert
-    for(int i=0; i<0x100; i++) for(int k=last1; k<0x10000; k++)
-        if(dt_dev_default_gamma[k] >= i)
-        {
-          last1 = k;
-          dt_dev_de_gamma[i] = k/(float)0x10000;
-          break;
-        }
-    dt_dev_set_gamma_array(dev, 0.1, 0.35, dt_dev_default_gamma);
-    printf("begin\n");
-    for(int k=0; k<0x10000; k++)
-    {
-      printf("%d %d\n", k, (int)(dt_dev_de_gamma[dt_dev_default_gamma[k]]*0x10000));
-    }
-    printf("end\n");
-#endif
-    float lin = dt_conf_get_float("gamma_linear");
-    float gam = dt_conf_get_float("gamma_gamma");
-    dt_dev_set_gamma_array(dev, lin, gam, dt_dev_default_gamma);
-    int last = 0; // invert
-    for(int i=0; i<0x100; i++) for(int k=last; k<0x10000; k++)
-        if(dt_dev_default_gamma[k] >= i)
-        {
-          last = k;
-          dt_dev_de_gamma[i] = k/(float)0x10000;
-          break;
-        }
+    dev->histogram_pre_tonecurve_max = -1;
+    dev->histogram_pre_levels_max = -1;
   }
-  for(int i=0; i<0x100; i++) dev->gamma[i] = dt_dev_default_gamma[i<<8];
 
   dev->iop_instance = 0;
   dev->iop = NULL;
@@ -145,13 +91,6 @@ void dt_dev_cleanup(dt_develop_t *dev)
 {
   if(!dev) return;
   // image_cache does not have to be unref'd, this is done outside develop module.
-  // unref used mipmap buffers:
-  if(dev->image)
-  {
-    dt_image_release(dev->image, DT_IMAGE_FULL, 'w');
-    dt_image_release(dev->image, DT_IMAGE_FULL, 'r');
-    if(dev->mipf) dt_image_release(dev->image, DT_IMAGE_MIPF, 'r');
-  }
   if(dev->pipe)
   {
     dt_dev_pixelpipe_cleanup(dev->pipe);
@@ -177,12 +116,13 @@ void dt_dev_cleanup(dt_develop_t *dev)
   }
   dt_pthread_mutex_destroy(&dev->history_mutex);
   free(dev->histogram);
-  free(dev->histogram_pre);
+  free(dev->histogram_pre_tonecurve);
+  free(dev->histogram_pre_levels);
 }
 
 void dt_dev_process_image(dt_develop_t *dev)
 {
-  if(!dev->image || /*dev->image_loading ||*/ !dev->gui_attached || dev->pipe->processing) return;
+  if(/*dev->image_loading ||*/ !dev->gui_attached || dev->pipe->processing) return;
   dt_job_t job;
   dt_dev_process_image_job_init(&job, dev);
   int err = dt_control_add_job_res(darktable.control, &job, DT_CTL_WORKER_2);
@@ -191,8 +131,7 @@ void dt_dev_process_image(dt_develop_t *dev)
 
 void dt_dev_process_preview(dt_develop_t *dev)
 {
-  // if(!dev->image || !dev->image->mipf || !dev->gui_attached/* || dev->preview_pipe->processing*/) return;
-  if(!dev->image || !dev->gui_attached) return;
+  if(!dev->gui_attached) return;
   dt_job_t job;
   dt_dev_process_preview_job_init(&job, dev);
   int err = dt_control_add_job_res(darktable.control, &job, DT_CTL_WORKER_3);
@@ -214,50 +153,34 @@ void dt_dev_invalidate_all(dt_develop_t *dev)
 
 void dt_dev_process_preview_job(dt_develop_t *dev)
 {
-  if(dev->image_loading && dt_image_lock_if_available(dev->image, DT_IMAGE_MIPF, 'r'))
+  dt_mipmap_buffer_t buf;
+  if(dev->image_loading)
   {
-    // raw is already loading, and we don't have a mipf yet. no use starting another file access, we wait.
+    // raw is already loading, no use starting another file access, we wait.
     return;
   }
-  else dt_image_release(dev->image, DT_IMAGE_MIPF, 'r');
 
   dt_control_log_busy_enter();
   dev->preview_pipe->input_timestamp = dev->timestamp;
   dev->preview_dirty = 1;
+
+  // lock if there, issue a background load, if not (best-effort for mip f). 
+  dt_mipmap_cache_read_get(darktable.mipmap_cache, &buf, dev->image_storage.id, DT_MIPMAP_F, 0);
+  if(!buf.buf)
+  {
+    dt_control_log_busy_leave();
+    return; // not loaded yet. load will issue a gtk redraw on completion, which in turn will trigger us again later.
+  }
+  // init pixel pipeline for preview.
+  dt_dev_pixelpipe_set_input(dev->preview_pipe, dev, (float *)buf.buf, buf.width, buf.height, dev->image_storage.width/(float)buf.width);
+
   if(dev->preview_loading)
   {
-    // prefetch and lock
-    if(dt_image_get(dev->image, DT_IMAGE_MIPF, 'r') != DT_IMAGE_MIPF)
-    {
-      dev->mipf = NULL;
-      dt_control_log_busy_leave();
-      return; // not loaded yet. load will issue a gtk redraw on completion, which in turn will trigger us again later.
-    }
-    dev->mipf = dev->image->mipf;
-    // init pixel pipeline for preview.
-    dt_image_get_mip_size(dev->image, DT_IMAGE_MIPF, &dev->mipf_width, &dev->mipf_height);
-    dt_image_get_exact_mip_size(dev->image, DT_IMAGE_MIPF, &dev->mipf_exact_width, &dev->mipf_exact_height);
-    dt_dev_pixelpipe_set_input(dev->preview_pipe, dev, dev->image->mipf, dev->mipf_width, dev->mipf_height, dev->image->width/(float)dev->mipf_width);
     dt_dev_pixelpipe_cleanup_nodes(dev->preview_pipe);
     dt_dev_pixelpipe_create_nodes(dev->preview_pipe, dev);
     dt_dev_pixelpipe_flush_caches(dev->preview_pipe);
     dev->preview_loading = 0;
   }
-  else
-  {
-    // FIXME: when dr mode is left before demosaic completes, this will never return the lock!
-    if(dt_image_get(dev->image, DT_IMAGE_MIPF, 'r') != DT_IMAGE_MIPF)
-    {
-      dev->mipf = NULL;
-      dt_control_log_busy_leave();
-      return;
-    }
-    dev->mipf = dev->image->mipf;
-    // make sure our newly locked input is also given to the pixel pipe.
-    dt_image_get_mip_size(dev->image, DT_IMAGE_MIPF, &dev->mipf_width, &dev->mipf_height);
-    dt_image_get_exact_mip_size(dev->image, DT_IMAGE_MIPF, &dev->mipf_exact_width, &dev->mipf_exact_height);
-    dt_dev_pixelpipe_set_input(dev->preview_pipe, dev, dev->image->mipf, dev->mipf_width, dev->mipf_height, dev->image->width/(float)dev->mipf_width);
-  }
 
   // if raw loaded, get new mipf
   if(dev->preview_input_changed)
@@ -271,8 +194,7 @@ restart:
   if(dev->gui_leaving)
   {
     dt_control_log_busy_leave();
-    dev->mipf = NULL;
-    dt_image_release(dev->image, DT_IMAGE_MIPF, 'r');
+    dt_mipmap_cache_read_release(darktable.mipmap_cache, &buf);
     return;
   }
   // adjust pipeline according to changed flag set by {add,pop}_history_item.
@@ -285,8 +207,7 @@ restart:
     if(dev->preview_loading || dev->preview_input_changed)
     {
       dt_control_log_busy_leave();
-      dev->mipf = NULL;
-      dt_image_release(dev->image, DT_IMAGE_MIPF, 'r');
+      dt_mipmap_cache_read_release(darktable.mipmap_cache, &buf);
       return;
     }
     else goto restart;
@@ -294,90 +215,62 @@ restart:
   dt_show_times(&start, "[dev_process_preview] pixel pipeline processing", NULL);
 
   dev->preview_dirty = 0;
-  dt_control_queue_draw_all();
   dt_control_log_busy_leave();
-  dev->mipf = NULL;
-  dt_image_release(dev->image, DT_IMAGE_MIPF, 'r');
-}
-
-// process preview to gain ldr-mipmaps:
-void dt_dev_process_to_mip(dt_develop_t *dev)
-{
-  // TODO: efficiency: check hash on preview_pipe->backbuf
-  if(dt_image_get_blocking(dev->image, DT_IMAGE_MIPF, 'r') != DT_IMAGE_MIPF)
-  {
-    fprintf(stderr, "[dev_process_to_mip] no float buffer is available yet!\n");
-    return; // not loaded yet.
-  }
-
-  if(!dev->preview_pipe)
-  {
-    // init pixel pipeline for preview.
-    dev->preview_pipe = (dt_dev_pixelpipe_t *)malloc(sizeof(dt_dev_pixelpipe_t));
-    dt_dev_pixelpipe_init(dev->preview_pipe);
-    dt_image_get_mip_size(dev->image, DT_IMAGE_MIPF, &dev->mipf_width, &dev->mipf_height);
-    dt_image_get_exact_mip_size(dev->image, DT_IMAGE_MIPF, &dev->mipf_exact_width, &dev->mipf_exact_height);
-    dt_dev_pixelpipe_set_input(dev->preview_pipe, dev, dev->image->mipf, dev->mipf_width, dev->mipf_height, dev->image->width/(float)dev->mipf_width);
-    dt_dev_pixelpipe_cleanup_nodes(dev->preview_pipe);
-    dt_dev_pixelpipe_create_nodes(dev->preview_pipe, dev);
-    dev->preview_loading = 0;
-  }
-
-  int wd, ht;
-  float fwd, fht;
-
-  dev->preview_downsampling = 1.0;
-  dev->preview_pipe->changed |= DT_DEV_PIPE_SYNCH;
-  dt_dev_process_preview_job(dev);
-
-  // now the real wd/ht is available.
-  dt_dev_get_processed_size(dev, &dev->image->output_width, &dev->image->output_height);
-  dt_image_get_mip_size(dev->image, DT_IMAGE_MIP4, &wd, &ht);
-  dt_image_get_exact_mip_size(dev->image, DT_IMAGE_MIP4, &fwd, &fht);
-
-  if(dt_image_alloc(dev->image, DT_IMAGE_MIP4))
-  {
-    fprintf(stderr, "[dev_process_to_mip] could not alloc mip4 to write mipmaps!\n");
-    dt_image_release(dev->image, DT_IMAGE_MIPF, 'r');
-    return;
-  }
-
-  dt_image_check_buffer(dev->image, DT_IMAGE_MIP4, sizeof(uint8_t)*4*wd*ht);
-  dt_pthread_mutex_lock(&(dev->preview_pipe->backbuf_mutex));
-
-  // don't if processing failed and backbuf's not there.
-  if(dev->preview_pipe->backbuf)
-  {
-    dt_iop_clip_and_zoom_8(dev->preview_pipe->backbuf, 0, 0, dev->preview_pipe->backbuf_width, dev->preview_pipe->backbuf_height,
-                           dev->preview_pipe->backbuf_width, dev->preview_pipe->backbuf_height,
-                           dev->image->mip[DT_IMAGE_MIP4], 0, 0, fwd, fht, wd, ht);
-
-  }
-  dt_image_release(dev->image, DT_IMAGE_MIP4, 'w');
-  dt_pthread_mutex_unlock(&(dev->preview_pipe->backbuf_mutex));
-
-  dt_image_update_mipmaps(dev->image);
-
-  dt_image_cache_flush(dev->image); // write new output size to db.
-  dt_image_release(dev->image, DT_IMAGE_MIP4, 'r');
-  dt_image_release(dev->image, DT_IMAGE_MIPF, 'r');
+  dt_mipmap_cache_read_release(darktable.mipmap_cache, &buf);
 }
 
 void dt_dev_process_image_job(dt_develop_t *dev)
 {
   dt_control_log_busy_enter();
+  // let gui know to draw preview instead of us, if it's there:
   dev->image_dirty = 1;
-  if(dev->image_loading) dt_dev_raw_load(dev, dev->image);
+
+  dt_mipmap_buffer_t buf;
+  dt_times_t start;
+  dt_get_times(&start);
+  dt_mipmap_cache_read_get(darktable.mipmap_cache, &buf, dev->image_storage.id, DT_MIPMAP_FULL, DT_MIPMAP_BLOCKING);
+  dt_show_times(&start, "[dev]", "to load the image.");
+
+  // copy over image now that width and height are sure to be correct:
+  const dt_image_t *img = dt_image_cache_read_get(darktable.image_cache, dev->image_storage.id);
+  dev->image_storage = *img;
+  // but don't lock the real thing, as that would avoid any writers to change stuff.
+  // (such as raw loading or star rating changes)
+  dt_image_cache_read_release(darktable.image_cache, img);
+
+  // failed to load raw?
+  if(!buf.buf) return;
+  
+  dt_dev_pixelpipe_set_input(dev->pipe, dev, (float *)buf.buf, buf.width, buf.height, 1.0);
+
+  if(dev->image_loading)
+  {
+    // init pixel pipeline
+    dt_dev_pixelpipe_cleanup_nodes(dev->pipe);
+    dt_dev_pixelpipe_create_nodes(dev->pipe, dev);
+    if(dev->image_force_reload) dt_dev_pixelpipe_flush_caches(dev->pipe);
+    dev->image_dirty = 1;
+    dev->image_force_reload = 0;
+    if(dev->gui_attached)
+    {
+      // during load, a mipf update could have been issued.
+      dev->preview_input_changed = 1;
+      dev->preview_dirty = 1;
+      dev->gui_synch = 1; // notify gui thread we want to synch (call gui_update in the modules)
+      dev->preview_pipe->changed |= DT_DEV_PIPE_SYNCH;
+    }
+    dev->pipe->changed |= DT_DEV_PIPE_SYNCH;
+  }
 
   dt_dev_zoom_t zoom;
   float zoom_x, zoom_y, scale;
   int x, y;
 
-  // printf("process: %d %d -> %d %d scale %f\n", x, y, dev->capwidth, dev->capheight, scale);
   // adjust pipeline according to changed flag set by {add,pop}_history_item.
 restart:
   if(dev->gui_leaving)
   {
+    dt_mipmap_cache_read_release(darktable.mipmap_cache, &buf);
     dt_control_log_busy_leave();
     return;
   }
@@ -390,110 +283,56 @@ restart:
   DT_CTL_GET_GLOBAL(zoom_y, dev_zoom_y);
 
   scale = dt_dev_get_zoom_scale(dev, zoom, 1.0f, 0);
-  dev->capwidth  = MIN(MIN(dev->width,  dev->pipe->processed_width *scale), DT_IMAGE_WINDOW_SIZE);
-  dev->capheight = MIN(MIN(dev->height, dev->pipe->processed_height*scale), DT_IMAGE_WINDOW_SIZE);
+  dev->capwidth  = MIN(MIN(dev->width,  dev->pipe->processed_width *scale), darktable.thumbnail_width);
+  dev->capheight = MIN(MIN(dev->height, dev->pipe->processed_height*scale), darktable.thumbnail_height);
   x = MAX(0, scale*dev->pipe->processed_width *(.5+zoom_x)-dev->capwidth/2);
   y = MAX(0, scale*dev->pipe->processed_height*(.5+zoom_y)-dev->capheight/2);
-#ifndef HAVE_GEGL
-  // only necessary for full pixels pipeline
-  assert(dev->capwidth  <= DT_IMAGE_WINDOW_SIZE);
-  assert(dev->capheight <= DT_IMAGE_WINDOW_SIZE);
-#endif
 
-  dt_times_t start;
   dt_get_times(&start);
   if(dt_dev_pixelpipe_process(dev->pipe, dev, x, y, dev->capwidth, dev->capheight, scale))
   {
+    // interrupted because image changed?
     if(dev->image_force_reload)
     {
+      dt_mipmap_cache_read_release(darktable.mipmap_cache, &buf);
       dt_control_log_busy_leave();
       return;
     }
+    // or because the pipeline changed?
     else goto restart;
   }
   dt_show_times(&start, "[dev_process_image] pixel pipeline processing", NULL);
 
   // maybe we got zoomed/panned in the meantime?
   if(dev->pipe->changed != DT_DEV_PIPE_UNCHANGED) goto restart;
-  dev->image_dirty = 0;
 
-  dt_control_queue_draw_all();
+  // cool, we got a new image!
+  dev->image_dirty = 0;
+  dev->image_loading = 0;
+
+  dt_mipmap_cache_read_release(darktable.mipmap_cache, &buf);
+  dt_control_queue_redraw_center();
   dt_control_log_busy_leave();
 }
 
-void dt_dev_raw_reload(dt_develop_t *dev)
+void dt_dev_reload_image(dt_develop_t *dev, const uint32_t imgid)
 {
+  const dt_image_t *image = dt_image_cache_read_get(darktable.image_cache, imgid);
+  dev->image_storage = *image;
+  dt_image_cache_read_release(darktable.image_cache, image);
   dev->image_force_reload = dev->image_loading = dev->preview_loading = 1;
-  dev->image->output_width = dev->image->output_height = 0;
   dev->pipe->changed |= DT_DEV_PIPE_SYNCH;
   dt_dev_invalidate(dev); // only invalidate image, preview will follow once it's loaded.
 }
 
-void dt_dev_raw_load(dt_develop_t *dev, dt_image_t *img)
-{
-  // only load if not already there.
-  if(dev->image_force_reload || dt_image_lock_if_available(dev->image, DT_IMAGE_FULL, 'r'))
-  {
-    int err;
-    // not loaded from cache because it is obviously not there yet.
-    if(dev->image_force_reload) dt_image_release(img, DT_IMAGE_FULL, 'r');
-restart:
-    dev->image_loading = 1;
-    dt_print(DT_DEBUG_CONTROL, "[run_job+] 99 %f imageio loading image %d\n", dt_get_wtime(), img->id);
-    dt_times_t start;
-    dt_get_times(&start);
-    err = dt_image_load(img, DT_IMAGE_FULL); // load and lock 'r'
-    dt_show_times(&start, "[dev_raw_load] imageio", "to load the image.");
-    dt_print(DT_DEBUG_CONTROL, "[run_job-] 99 %f imageio loading image %d\n", dt_get_wtime(), img->id);
-    if(err)
-    {
-      // couldn't load image (cache slots full?)
-      fprintf(stderr, "[dev_raw_load] failed to load image %s!\n", img->filename);
-      // spin lock:
-      sleep(1);
-      goto restart;
-    }
-
-    // obsoleted by another job?
-    if(dev->image != img)
-    {
-      printf("[dev_raw_load] recovering from obsoleted read!\n");
-      img = dev->image;
-      dt_image_release(img, DT_IMAGE_FULL, 'r');
-      goto restart;
-    }
-  }
-  if(dev->gui_attached)
-  {
-    // reset output width
-    dev->image->output_width = dev->image->output_height = 0;
-    // init pixel pipeline
-    dt_dev_pixelpipe_set_input(dev->pipe, dev, dev->image->pixels, dev->image->width, dev->image->height, 1.0);
-    dt_dev_pixelpipe_cleanup_nodes(dev->pipe);
-    dt_dev_pixelpipe_create_nodes(dev->pipe, dev);
-    if(dev->image_force_reload) dt_dev_pixelpipe_flush_caches(dev->pipe);
-    dev->image_loading = 0;
-    dev->image_dirty = 1;
-    dev->image_force_reload = 0;
-    // during load, a mipf update could have been issued.
-    dev->preview_input_changed = 1;
-    dev->preview_dirty = 1;
-    dev->gui_synch = 1; // notify gui thread we want to synch
-    dev->preview_pipe->changed |= DT_DEV_PIPE_SYNCH;
-    dev->pipe->changed |= DT_DEV_PIPE_SYNCH;
-    dt_dev_process_image(dev);
-  }
-}
-
 float dt_dev_get_zoom_scale(dt_develop_t *dev, dt_dev_zoom_t zoom, int closeup_factor, int preview)
 {
-  float zoom_scale, prevw, prevh;
+  float zoom_scale;
   // set processed width to something useful while image is not there yet:
   int procw, proch;
   dt_dev_get_processed_size(dev, &procw, &proch);
   const float w = preview ? dev->preview_pipe->backbuf_width  : procw;
   const float h = preview ? dev->preview_pipe->backbuf_height : proch;
-  if(preview) dt_image_get_exact_mip_size(dev->image, DT_IMAGE_MIP4, &prevw, &prevh);
   switch(zoom)
   {
     case DT_ZOOM_FIT:
@@ -514,22 +353,11 @@ float dt_dev_get_zoom_scale(dt_develop_t *dev, dt_dev_zoom_t zoom, int closeup_f
   return zoom_scale;
 }
 
-void dt_dev_load_preview(dt_develop_t *dev, dt_image_t *image)
+void dt_dev_load_image(dt_develop_t *dev, const uint32_t imgid)
 {
-  dev->image = image;
-  dev->preview_loading = 1;
-  if(dt_image_get_blocking(dev->image, DT_IMAGE_MIPF, 'r') == DT_IMAGE_MIPF) dev->mipf = dev->image->mipf; // prefetch and lock
-  else dev->mipf = NULL;
-  dev->preview_dirty = 1;
-
-  dev->iop = dt_iop_load_modules(dev);
-  dt_dev_read_history(dev);
-}
-
-
-void dt_dev_load_image(dt_develop_t *dev, dt_image_t *image)
-{
-  dev->image = image;
+  const dt_image_t *image = dt_image_cache_read_get(darktable.image_cache, imgid);
+  dev->image_storage = *image;
+  dt_image_cache_read_release(darktable.image_cache, image);
   if(dev->pipe)
   {
     dev->pipe->processed_width  = 0;
@@ -537,21 +365,16 @@ void dt_dev_load_image(dt_develop_t *dev, dt_image_t *image)
   }
   dev->image_loading = 1;
   dev->preview_loading = 1;
-  if(dev->gui_attached && dt_image_get(dev->image, DT_IMAGE_MIPF, 'r') == DT_IMAGE_MIPF) dev->mipf = dev->image->mipf; // prefetch and lock
-  else dev->mipf = NULL;
   dev->image_dirty = dev->preview_dirty = 1;
 
-  if(!dev->gui_attached)
-    dt_dev_raw_load(dev, dev->image);
-
   dev->iop = dt_iop_load_modules(dev);
   dt_dev_read_history(dev);
 }
 
 void dt_dev_configure (dt_develop_t *dev, int wd, int ht)
 {
-  wd = MIN(DT_IMAGE_WINDOW_SIZE, wd);
-  ht = MIN(DT_IMAGE_WINDOW_SIZE, ht);
+  wd = MIN(darktable.thumbnail_width, wd);
+  ht = MIN(darktable.thumbnail_height, ht);
   if(dev->width != wd || dev->height != ht)
   {
     dev->width  = wd;
@@ -563,24 +386,24 @@ void dt_dev_configure (dt_develop_t *dev, int wd, int ht)
 }
 
 // helper used to synch a single history item with db
-int dt_dev_write_history_item(dt_image_t *image, dt_dev_history_item_t *h, int32_t num)
+int dt_dev_write_history_item(const dt_image_t *image, dt_dev_history_item_t *h, int32_t num)
 {
   if(!image) return 1;
   sqlite3_stmt *stmt;
-  DT_DEBUG_SQLITE3_PREPARE_V2(darktable.db, "select num from history where imgid = ?1 and num = ?2", -1, &stmt, NULL);
+  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "select num from history where imgid = ?1 and num = ?2", -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, image->id);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 2, num);
   if(sqlite3_step(stmt) != SQLITE_ROW)
   {
     sqlite3_finalize(stmt);
-    DT_DEBUG_SQLITE3_PREPARE_V2(darktable.db, "insert into history (imgid, num) values (?1, ?2)", -1, &stmt, NULL);
+    DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "insert into history (imgid, num) values (?1, ?2)", -1, &stmt, NULL);
     DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, image->id);
     DT_DEBUG_SQLITE3_BIND_INT(stmt, 2, num);
     sqlite3_step (stmt);
   }
   // printf("[dev write history item] writing %d - %s params %f %f\n", h->module->instance, h->module->op, *(float *)h->params, *(((float *)h->params)+1));
   sqlite3_finalize (stmt);
-  DT_DEBUG_SQLITE3_PREPARE_V2(darktable.db, "update history set operation = ?1, op_params = ?2, module = ?3, enabled = ?4, blendop_params = ?7 where imgid = ?5 and num = ?6", -1, &stmt, NULL);
+  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "update history set operation = ?1, op_params = ?2, module = ?3, enabled = ?4, blendop_params = ?7 where imgid = ?5 and num = ?6", -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, h->module->op, strlen(h->module->op), SQLITE_TRANSIENT);
   DT_DEBUG_SQLITE3_BIND_BLOB(stmt, 2, h->params, h->module->params_size, SQLITE_TRANSIENT);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 3, h->module->version());
@@ -600,10 +423,6 @@ void dt_dev_add_history_item(dt_develop_t *dev, dt_iop_module_t *module, gboolea
   dt_pthread_mutex_lock(&dev->history_mutex);
   if(dev->gui_attached)
   {
-    // if gui_attached pop all operations down to dev->history_end
-    dt_control_clear_history_items (dev->history_end-1);
-
-    // remove unused history items:
     GList *history = g_list_nth (dev->history, dev->history_end);
     while(history)
     {
@@ -646,12 +465,6 @@ void dt_dev_add_history_item(dt_develop_t *dev, dt_iop_module_t *module, gboolea
       if(module->flags() & IOP_FLAGS_SUPPORTS_BLENDING)
         memcpy(hist->blend_params, module->blend_params, sizeof(dt_develop_blend_params_t));
 
-      if(dev->gui_attached)
-      {
-        char label[512]; // print on/off
-        dt_dev_get_history_item_label(hist, label, 512);
-        dt_control_add_history_item(dev->history_end-1, label);
-      }
       dev->history = g_list_append(dev->history, hist);
       dev->pipe->changed |= DT_DEV_PIPE_SYNCH;
       dev->preview_pipe->changed |= DT_DEV_PIPE_SYNCH; // topology remains, as modules are fixed for now.
@@ -667,9 +480,8 @@ void dt_dev_add_history_item(dt_develop_t *dev, dt_iop_module_t *module, gboolea
         memcpy(hist->blend_params, module->blend_params, sizeof(dt_develop_blend_params_t));
 
       // if the user changed stuff and the module is still not enabled, do it:
-      if(strcmp(module->op, "rawimport") && !hist->enabled && !module->enabled)
+      if(!hist->enabled && !module->enabled)
       {
-        // only if not rawimport. this always stays off.
         module->enabled = 1;
         if(module->off)
         {
@@ -705,16 +517,17 @@ void dt_dev_add_history_item(dt_develop_t *dev, dt_iop_module_t *module, gboolea
 
   if(dev->gui_attached)
   {
-    // update history (on) (off) annotation
-    dt_control_clear_history_items(dev->history_end);
-    dt_control_queue_draw_all();
+    /* signal that history has changed */
+    dt_control_signal_raise(darktable.signals, DT_SIGNAL_DEVELOP_HISTORY_CHANGE);
+
+    /* redraw */
+    dt_control_queue_redraw_center();
   }
 }
 
 void dt_dev_reload_history_items(dt_develop_t *dev)
 {
   dt_dev_pop_history_items(dev, 0);
-  dt_control_clear_history_items(dev->history_end-1);
   // remove unused history items:
   GList *history = g_list_nth(dev->history, dev->history_end);
   while(history)
@@ -771,22 +584,23 @@ void dt_dev_pop_history_items(dt_develop_t *dev, int32_t cnt)
   darktable.gui->reset = 0;
   dt_dev_invalidate_all(dev);
   dt_pthread_mutex_unlock(&dev->history_mutex);
-  dt_control_queue_draw_all();
+  dt_control_queue_redraw_center();
 }
 
 void dt_dev_write_history(dt_develop_t *dev)
 {
   sqlite3_stmt *stmt;
+
   gboolean changed = FALSE;
-  DT_DEBUG_SQLITE3_PREPARE_V2(darktable.db, "delete from history where imgid = ?1", -1, &stmt, NULL);
-  DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, dev->image->id);
+  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "delete from history where imgid = ?1", -1, &stmt, NULL);
+  DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, dev->image_storage.id);
   sqlite3_step(stmt);
   sqlite3_finalize (stmt);
   GList *history = dev->history;
   for(int i=0; i<dev->history_end && history; i++)
   {
     dt_dev_history_item_t *hist = (dt_dev_history_item_t *)(history->data);
-    (void)dt_dev_write_history_item(dev->image, hist, i);
+    (void)dt_dev_write_history_item(&dev->image_storage, hist, i);
     history = g_list_next(history);
     changed = TRUE;
   }
@@ -795,19 +609,18 @@ void dt_dev_write_history(dt_develop_t *dev)
   guint tagid = 0;
   dt_tag_new("darktable|changed",&tagid); 
   if(changed)
-    dt_tag_attach(tagid, dev->image->id);
+    dt_tag_attach(tagid, dev->image_storage.id);
   else
-    dt_tag_detach(tagid, dev->image->id);
+    dt_tag_detach(tagid, dev->image_storage.id);
 
 }
 
 void dt_dev_read_history(dt_develop_t *dev)
 {
-  if(dev->gui_attached) dt_control_clear_history_items(-1);
-  if(!dev->image) return;
+  if(!dev->image_storage.id) return;
   sqlite3_stmt *stmt;
-  DT_DEBUG_SQLITE3_PREPARE_V2(darktable.db, "select * from history where imgid = ?1 order by num", -1, &stmt, NULL);
-  DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, dev->image->id);
+  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "select * from history where imgid = ?1 order by num", -1, &stmt, NULL);
+  DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, dev->image_storage.id);
   dev->history_end = 0;
   while(sqlite3_step(stmt) == SQLITE_ROW)
   {
@@ -818,6 +631,13 @@ void dt_dev_read_history(dt_develop_t *dev)
 
     GList *modules = dev->iop;
     const char *opname = (const char *)sqlite3_column_text(stmt, 3);
+    if(!opname)
+    {
+      fprintf(stderr, "[dev_read_history] database history for image `%s' seems to be corrupted!\n", dev->image_storage.filename);
+      free(hist);
+      continue;
+    }
+   
     hist->module = NULL;
     while(modules)
     {
@@ -831,7 +651,7 @@ void dt_dev_read_history(dt_develop_t *dev)
     }
     if(!hist->module)
     {
-      fprintf(stderr, "[dev_read_history] the module `%s' requested by image `%s' is not installed on this computer!\n", opname, dev->image->filename);
+      fprintf(stderr, "[dev_read_history] the module `%s' requested by image `%s' is not installed on this computer!\n", opname, dev->image_storage.filename);
       free(hist);
       continue;
     }
@@ -848,9 +668,9 @@ void dt_dev_read_history(dt_develop_t *dev)
         free(hist->params);
         free(hist->blend_params);
         fprintf(stderr, "[dev_read_history] module `%s' version mismatch: history is %d, dt %d.\n", hist->module->op, modversion, hist->module->version());
-        const char *fname = dev->image->filename + strlen(dev->image->filename);
-        while(fname > dev->image->filename && *fname != '/') fname --;
-        if(fname > dev->image->filename) fname++;
+        const char *fname = dev->image_storage.filename + strlen(dev->image_storage.filename);
+        while(fname > dev->image_storage.filename && *fname != '/') fname --;
+        if(fname > dev->image_storage.filename) fname++;
         dt_control_log(_("%s: module `%s' version mismatch: %d != %d"), fname, hist->module->op, hist->module->version(), modversion);
         free(hist);
         continue;
@@ -871,19 +691,16 @@ void dt_dev_read_history(dt_develop_t *dev)
     // printf("[dev read history] img %d number %d for operation %d - %s params %f %f\n", sqlite3_column_int(stmt, 0), sqlite3_column_int(stmt, 1), instance, hist->module->op, *(float *)hist->params, *(((float*)hist->params)+1));
     dev->history = g_list_append(dev->history, hist);
     dev->history_end ++;
-
-    if(dev->gui_attached)
-    {
-      char label[256];
-      dt_dev_get_history_item_label(hist, label, 256);
-      dt_control_add_history_item(dev->history_end-1, label);
-    }
   }
+
   if(dev->gui_attached)
   {
     dev->pipe->changed |= DT_DEV_PIPE_SYNCH;
     dev->preview_pipe->changed |= DT_DEV_PIPE_SYNCH; // again, fixed topology for now.
     dt_dev_invalidate_all(dev);
+
+    /* signal history changed */
+    dt_control_signal_raise(darktable.signals,DT_SIGNAL_DEVELOP_HISTORY_CHANGE);
   }
   sqlite3_finalize (stmt);
 }
@@ -931,7 +748,8 @@ void dt_dev_check_zoom_bounds(dt_develop_t *dev, float *zoom_x, float *zoom_y, d
 
 void dt_dev_get_processed_size(const dt_develop_t *dev, int *procw, int *proch)
 {
-  const float scale = dev->image->width/dev->mipf_exact_width;
+  // [jo] TODO: i hate this whole function. thread-safe? get rid of it!
+  const float scale = dev->preview_pipe ? (dev->preview_pipe->iscale / dev->preview_downsampling) : 1.0f;
   *procw = dev->pipe && dev->pipe->processed_width  ? dev->pipe->processed_width  : scale * dev->preview_pipe->processed_width;
   *proch = dev->pipe && dev->pipe->processed_height ? dev->pipe->processed_height : scale * dev->preview_pipe->processed_height;
 }
@@ -957,20 +775,108 @@ void dt_dev_get_pointer_zoom_pos(dt_develop_t *dev, const float px, const float
 
 void dt_dev_get_history_item_label(dt_dev_history_item_t *hist, char *label, const int cnt)
 {
-  if(strcmp(hist->module->op, "rawimport"))
-    g_snprintf(label, cnt, "%s (%s)", hist->module->name(), hist->enabled ? _("on") : _("off"));
-  else
-    g_snprintf(label, cnt, "%s", hist->module->name());
+  g_snprintf(label, cnt, "%s (%s)", hist->module->name(), hist->enabled ? _("on") : _("off"));
 }
 
 int
-dt_dev_is_current_image (dt_develop_t *dev, int imgid)
+dt_dev_is_current_image (dt_develop_t *dev, uint32_t imgid)
 {
-  return (dev->image && dev->image->id==imgid)?1:0;
+  return (dev->image_storage.id==imgid)?1:0;
 }
 
-void
-dt_dev_invalidate_from_gui (dt_develop_t *dev)
+gboolean dt_dev_exposure_hooks_available(dt_develop_t *dev)
+{
+  /* check if exposure iop module has registered its hooks */
+  if( dev->proxy.exposure.module && 
+      dev->proxy.exposure.set_black && dev->proxy.exposure.get_black &&
+      dev->proxy.exposure.set_white && dev->proxy.exposure.get_white)
+    return TRUE;
+
+  return FALSE;
+}
+
+void dt_dev_exposure_reset_defaults(dt_develop_t *dev)
+{
+  if (!dev->proxy.exposure.module) return;
+
+  dt_iop_module_t *exposure = dev->proxy.exposure.module;
+  memcpy(exposure->params, exposure->default_params, exposure->params_size);
+  exposure->gui_update(exposure);
+  dt_dev_add_history_item(exposure->dev, exposure, TRUE);
+}
+
+void dt_dev_exposure_set_white(dt_develop_t *dev, const float white)
+{
+   if (dev->proxy.exposure.module && dev->proxy.exposure.set_white)
+     dev->proxy.exposure.set_white(dev->proxy.exposure.module, white);
+}
+
+float dt_dev_exposure_get_white(dt_develop_t *dev)
+{
+  if (dev->proxy.exposure.module && dev->proxy.exposure.set_white)
+     return dev->proxy.exposure.get_white(dev->proxy.exposure.module);
+
+  return 0.0;
+}
+
+void dt_dev_exposure_set_black(dt_develop_t *dev, const float black)
+{
+  if (dev->proxy.exposure.module && dev->proxy.exposure.set_black)
+     dev->proxy.exposure.set_black(dev->proxy.exposure.module, black);
+}
+
+float dt_dev_exposure_get_black(dt_develop_t *dev)
+{
+  if (dev->proxy.exposure.module && dev->proxy.exposure.set_black)
+     return dev->proxy.exposure.get_black(dev->proxy.exposure.module);
+
+  return 0.0;
+}
+
+gboolean dt_dev_modulegroups_available(dt_develop_t *dev) 
+{
+  if(dev->proxy.modulegroups.module && dev->proxy.modulegroups.set && dev->proxy.modulegroups.get)
+    return TRUE;
+
+  return FALSE;
+}
+
+void dt_dev_modulegroups_set(dt_develop_t *dev, uint32_t group)
+{
+  if(dev->proxy.modulegroups.module && dev->proxy.modulegroups.set)
+    dev->proxy.modulegroups.set(dev->proxy.modulegroups.module, group);
+}
+
+uint32_t dt_dev_modulegroups_get(dt_develop_t *dev)
+{
+  if(dev->proxy.modulegroups.module && dev->proxy.modulegroups.get)
+    return dev->proxy.modulegroups.get(dev->proxy.modulegroups.module);
+
+  return 0;
+}
+
+gboolean dt_dev_modulegroups_test(dt_develop_t *dev, uint32_t group, uint32_t iop_group)
+{
+  if(dev->proxy.modulegroups.module && dev->proxy.modulegroups.test)
+    return dev->proxy.modulegroups.test(dev->proxy.modulegroups.module, group, iop_group); 
+  return FALSE;
+}
+
+void dt_dev_modulegroups_switch(dt_develop_t *dev, dt_iop_module_t *module)
+{
+  if (dev->proxy.modulegroups.module && dev->proxy.modulegroups.switch_group)
+    dev->proxy.modulegroups.switch_group(dev->proxy.modulegroups.module, module);
+}
+
+
+void dt_dev_snapshot_request(dt_develop_t *dev, const char *filename)
+{
+  dev->proxy.snapshot.filename = filename;
+  dev->proxy.snapshot.request = TRUE;
+  dt_control_queue_redraw_center();
+}
+
+void dt_dev_invalidate_from_gui (dt_develop_t *dev)
 {
   dt_dev_pop_history_items(darktable.develop, darktable.develop->history_end);
 }
