@@ -38,6 +38,29 @@
 
 #define max(a,b) ((a) > (b) ? (a) : (b))
 
+static char *_pipe_type_to_str(int pipe_type)
+{
+  char *r;
+
+  switch(pipe_type)
+  {
+    case DT_DEV_PIXELPIPE_PREVIEW:
+      r = "preview";
+      break;
+    case DT_DEV_PIXELPIPE_FULL:
+      r = "full";
+      break;
+    case DT_DEV_PIXELPIPE_THUMBNAIL:
+      r = "thumbnail";
+      break;
+    case DT_DEV_PIXELPIPE_EXPORT:
+    default:
+      r = "export";
+    break;
+  }
+  return r;
+}
+
 int dt_dev_pixelpipe_init_export(dt_dev_pixelpipe_t *pipe, int32_t width, int32_t height)
 {
   int res = dt_dev_pixelpipe_init_cached(pipe, 4*sizeof(float)*width*height, 2);
@@ -45,6 +68,13 @@ int dt_dev_pixelpipe_init_export(dt_dev_pixelpipe_t *pipe, int32_t width, int32_
   return res;
 }
 
+int dt_dev_pixelpipe_init_thumbnail(dt_dev_pixelpipe_t *pipe, int32_t width, int32_t height)
+{
+  int res = dt_dev_pixelpipe_init_cached(pipe, 4*sizeof(float)*width*height, 2);
+  pipe->type = DT_DEV_PIXELPIPE_THUMBNAIL;
+  return res;
+}
+
 int dt_dev_pixelpipe_init(dt_dev_pixelpipe_t *pipe)
 {
   int res = dt_dev_pixelpipe_init_cached(pipe, 4*sizeof(float)*darktable.thumbnail_width*darktable.thumbnail_height, 5);
@@ -326,11 +356,19 @@ dt_dev_pixelpipe_process_rec(dt_dev_pixelpipe_t *pipe, dt_develop_t *dev, void *
         if(roi_in.scale == 1.0f)
         {
           // fast branch for 1:1 pixel copies.
+
+          // last minute clamping to catch potential out-of-bounds in roi_in and roi_out
+
+          const int in_x = MAX(roi_in.x, 0);
+          const int in_y = MAX(roi_in.y, 0);
+          const int cp_width = MIN(roi_out->width, pipe->iwidth - in_x);
+          const int cp_height = MIN(roi_out->height, pipe->iheight - in_y);
+
 #ifdef _OPENMP
           #pragma omp parallel for schedule(static) default(none) shared(pipe,roi_out,roi_in,output)
 #endif
-          for(int j=0; j<MIN(roi_out->height, pipe->iheight-roi_in.y); j++)
-            memcpy(((char *)*output) + bpp*j*roi_out->width, ((char *)pipe->input) + bpp*(roi_in.x + (roi_in.y + j)*pipe->iwidth), bpp*roi_out->width);
+          for(int j=0; j<cp_height; j++)
+            memcpy(((char *)*output) + bpp*j*roi_out->width, ((char *)pipe->input) + bpp*(in_x + (in_y + j)*pipe->iwidth), bpp*cp_width);
         }
         else
         {
@@ -359,7 +397,7 @@ dt_dev_pixelpipe_process_rec(dt_dev_pixelpipe_t *pipe, dt_develop_t *dev, void *
         dt_iop_clip_and_zoom(*output, pipe->input, roi_out, &roi_in, roi_out->width, pipe->iwidth);
       }
     }
-    dt_show_times(&start, "[dev_pixelpipe]", "initing base buffer [%s]", pipe->type == DT_DEV_PIXELPIPE_PREVIEW ? "preview" : (pipe->type == DT_DEV_PIXELPIPE_FULL ? "full" : "export"));
+    dt_show_times(&start, "[dev_pixelpipe]", "initing base buffer [%s]", _pipe_type_to_str(pipe->type));
     dt_pthread_mutex_unlock(&pipe->busy_mutex);
   }
   else
@@ -754,7 +792,7 @@ dt_dev_pixelpipe_process_rec(dt_dev_pixelpipe_t *pipe, dt_develop_t *dev, void *
 #endif
 
     dt_show_times(&start, "[dev_pixelpipe]", "processing `%s' [%s]", module->name(),
-                  pipe->type == DT_DEV_PIXELPIPE_PREVIEW ? "preview" : (pipe->type == DT_DEV_PIXELPIPE_FULL ? "full" : "export"));
+                  _pipe_type_to_str(pipe->type));
     // in case we get this buffer from the cache, also get the processed max:
     for(int k=0; k<3; k++) piece->processed_maximum[k] = pipe->processed_maximum[k];
     dt_pthread_mutex_unlock(&pipe->busy_mutex);
@@ -1240,7 +1278,7 @@ restart:
     dt_pthread_mutex_unlock(&pipe->busy_mutex);
     dt_dev_pixelpipe_flush_caches(pipe);
     dt_dev_pixelpipe_change(pipe, dev);
-    dt_print(DT_DEBUG_OPENCL, "[pixelpipe_process] [%s] falling back to cpu path\n", pipe->type == DT_DEV_PIXELPIPE_PREVIEW ? "preview" : (pipe->type == DT_DEV_PIXELPIPE_FULL ? "full" : "export"));
+    dt_print(DT_DEBUG_OPENCL, "[pixelpipe_process] [%s] falling back to cpu path\n", _pipe_type_to_str(pipe->type));
     goto restart;  // try again (this time without opencl)
   }
 
