@@ -95,18 +95,18 @@ default_process_tiling (struct dt_iop_module_t *self, struct dt_dev_pixelpipe_io
   }
 
   /* calculate optimal size of tiles */
-  float available = dt_conf_get_int("host_memory_limit")*1024*1024;
-  assert(available >= 500*1024*1024);
+  float available = (float)dt_conf_get_int("host_memory_limit")*1024.0f*1024.0f;
+  assert(available >= 500.0f*1024.0f*1024.0f);
   /* correct for size of ivoid and ovoid which are needed on top of tiling */
-  available = max(available - roi_out->width * roi_out->height * (in_bpp + out_bpp) - tiling.overhead, 0);
+  available = fmax(available - roi_out->width * roi_out->height * (in_bpp + out_bpp) - tiling.overhead, 0);
 
   /* we ignore the above value if singlebuffer_limit (is defined and) is higher than available/tiling.factor.
      this will mainly allow tiling for modules with high and "unpredictable" memory demand which is
      reflected in high values of tiling.factor (take bilateral noise reduction as an example). */
-  float singlebuffer = dt_conf_get_int("singlebuffer_limit")*1024*1024;
-  singlebuffer = max(singlebuffer, 1024*1024);
+  float singlebuffer = (float)dt_conf_get_int("singlebuffer_limit")*1024.0f*1024.0f;
+  singlebuffer = fmax(singlebuffer, 2.0f*1024.0f*1024.0f);
   assert(tiling.factor > 1.0f);
-  singlebuffer = max(available / tiling.factor, singlebuffer);
+  singlebuffer = fmax(available / tiling.factor, singlebuffer);
 
   int width = roi_out->width;
   int height = roi_out->height;
@@ -333,7 +333,7 @@ default_process_tiling_cl (struct dt_iop_module_t *self, struct dt_dev_pixelpipe
 
 
   /* calculate optimal size of tiles */
-  float headroom = (float)dt_conf_get_int("opencl_memory_headroom")*1024*1024;
+  float headroom = (float)dt_conf_get_int("opencl_memory_headroom")*1024.0f*1024.0f;
   headroom = fmin(fmax(headroom, 0.0f), (float)darktable.opencl->dev[devid].max_global_mem);
   const float available = darktable.opencl->dev[devid].max_global_mem - headroom;
   const float singlebuffer = fmin(fmax((available - tiling.overhead) / tiling.factor, 0.0f), darktable.opencl->dev[devid].max_mem_alloc);
