@@ -63,6 +63,13 @@ _button_expose (GtkWidget *widget, GdkEventExpose *event)
   /* set inner border */
   int border = (flags&CPF_DO_NOT_USE_BORDER)?2:4;
 
+  /* prelight */
+  if (state == GTK_STATE_PRELIGHT)
+    flags |= CPF_PRELIGHT;
+  else
+    flags &=~CPF_PRELIGHT;
+
+
   /* create pango text settings if label exists */
   PangoLayout *layout=NULL;
   int pw=0,ph=0;
@@ -107,6 +114,8 @@ _button_expose (GtkWidget *widget, GdkEventExpose *event)
                    x, y, width, height);
   }
 
+  if (flags & CPF_IGNORE_FG_STATE)
+    state = GTK_STATE_NORMAL;
 
   cairo_set_source_rgb (cr,
                         style->fg[state].red/65535.0,
@@ -116,10 +125,6 @@ _button_expose (GtkWidget *widget, GdkEventExpose *event)
   /* draw icon */
   if (DTGTK_BUTTON (widget)->icon)
   {
-//     if (flags & CPF_IGNORE_FG_STATE)
-//       state = GTK_STATE_NORMAL;
-
-
     if (text)
       DTGTK_BUTTON (widget)->icon (cr,x+border,y+border,height-(border*2),height-(border*2),flags);
     else
@@ -182,32 +187,12 @@ GtkType dtgtk_button_get_type()
   return dtgtk_button_type;
 }
 
-//static void button_click_callback(GtkAccelGroup *accel_group,
-//                                    GObject *acceleratable, guint keyval,
-//                                    GdkModifierType modifier, gpointer data)
-//{
-//	GtkDarktableButton *button=DTGTK_BUTTON(data);
-//	g_signal_emit_by_name(G_OBJECT(button),"activate");
-//}
-//void gtk_button_set_accel(GtkButton *button, GtkAccelGroup *accel_group, const gchar *accel_path)
-//{
-//  dt_accel_group_connect_by_path(accel_group,
-//                                 accel_path,
-//                                 g_cclosure_new(
-//                                     G_CALLBACK(button_click_callback),
-//                                     (gpointer)button, NULL));
-//}
-//void dtgtk_button_set_accel(GtkDarktableButton *button, GtkAccelGroup *accel_group, const gchar *accel_path)
-//{
-//  gtk_button_set_accel(GTK_BUTTON(button), accel_group,accel_path);
-//}
-//void gtk_button_init_accel(GtkAccelGroup *accel_group, const gchar *accel_path)
-//{
-//  gtk_accel_map_add_entry(accel_path, 0, 0);
-//  dt_accel_group_connect_by_path(accel_group, accel_path,NULL);
-//}
-//void dtgtk_button_init_accel(GtkAccelGroup *accel_group, const gchar *accel_path)
-//{
-//  gtk_button_init_accel(accel_group,accel_path);
-//}
+void dtgtk_button_set_paint(GtkDarktableButton *button,
+                            DTGTKCairoPaintIconFunc paint,
+                            gint paintflags)
+{
+  button->icon = paint;
+  button->icon_flags = paintflags;
+}
+
 // kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
