@@ -65,8 +65,7 @@ static gboolean _slider_enter_notify_event(GtkWidget *widget, GdkEventCrossing *
 // Slider entry events
 static gboolean _slider_entry_key_event(GtkWidget *widget,GdkEventKey *event, gpointer data);
 
-static guint _signals[SLIDER_LAST_SIGNAL] = { 0 };
-//static char accel_name_builder[1024];
+static guint _slider_signals[SLIDER_LAST_SIGNAL] = { 0 };
 
 void _slider_get_value_area(GtkWidget *widget,GdkRectangle *rect)
 {
@@ -104,9 +103,10 @@ static void _slider_class_init (GtkDarktableSliderClass *klass)
   widget_class->enter_notify_event = _slider_enter_notify_event;
   widget_class->leave_notify_event = _slider_enter_notify_event;
   //object_class->destroy = _slider_destroy;
-  _signals[VALUE_CHANGED] = g_signal_new(
+  _slider_signals[VALUE_CHANGED] = g_signal_new(
                               "value-changed",
-                              G_TYPE_OBJECT, G_SIGNAL_RUN_LAST,
+                              G_TYPE_FROM_CLASS(klass), 
+			      G_SIGNAL_RUN_LAST,
                               0,NULL,NULL,
                               g_cclosure_marshal_VOID__VOID,
                               GTK_TYPE_NONE,0);
@@ -141,19 +141,25 @@ static void _slider_init (GtkDarktableSlider *slider)
   dt_gui_key_accel_block_on_focus (slider->entry);
 }
 
+#if 0 // Deprecated the delayed value thingy
 static gboolean _slider_postponed_value_change(gpointer data)
 {
-  gdk_threads_enter();
-  if(DTGTK_SLIDER(data)->is_changed==TRUE)
+  gboolean i_own_lock = dt_control_gdk_lock();
+
+  if (DTGTK_SLIDER(data)->is_changed==TRUE)
   {
     g_signal_emit_by_name(G_OBJECT(data),"value-changed");
     if(DTGTK_SLIDER(data)->type==DARKTABLE_SLIDER_VALUE)
       DTGTK_SLIDER(data)->is_changed=FALSE;
   }
-  gdk_threads_leave();
+
+  if (i_own_lock) dt_control_gdk_unlock();
+
   return DTGTK_SLIDER(data)->is_dragging;	// This is called by the gtk mainloop and is threadsafe
 }
 
+#endif
+
 static gboolean _slider_button_press(GtkWidget *widget, GdkEventButton *event)
 {
   GtkDarktableSlider *slider=DTGTK_SLIDER(widget);
@@ -192,7 +198,9 @@ static gboolean _slider_button_press(GtkWidget *widget, GdkEventButton *event)
       slider->is_dragging=TRUE;
       slider->prev_x_root=event->x_root;
       if( slider->type==DARKTABLE_SLIDER_BAR) slider->is_changed=TRUE;
-      g_timeout_add(DTGTK_SLIDER_VALUE_CHANGED_DELAY, _slider_postponed_value_change,widget);
+#if 0 // Deprecate
+      g_timeout_add(DTGTK_SLIDER_VALUE_CHANGED_DELAY, _slider_postponed_value_change, widget);
+#endif
     }
   }
   else if(event->button == 1 && event->type == GDK_2BUTTON_PRESS)
@@ -239,6 +247,7 @@ static gboolean _slider_button_release(GtkWidget *widget, GdkEventButton *event)
       }
     }
     slider->is_dragging=FALSE;
+    g_signal_emit_by_name(G_OBJECT(widget),"value-changed");
   }
   return TRUE;
 }
@@ -345,6 +354,7 @@ static gboolean _slider_motion_notify(GtkWidget *widget, GdkEventMotion *event)
       }
     }
 
+    g_signal_emit_by_name(G_OBJECT(widget),"value-changed");
 
     gtk_widget_draw(widget,NULL);
     slider->prev_x_root = event->x_root;
@@ -456,6 +466,7 @@ static gboolean _slider_expose(GtkWidget *widget, GdkEventExpose *event)
   if (widget->allocation.width<=1) return FALSE;
 
   GtkStyle *style=gtk_rc_get_style_by_paths(gtk_settings_get_default(), NULL,"GtkButton", GTK_TYPE_BUTTON);
+  if(!style) style = gtk_rc_get_style(widget);
   GtkDarktableSlider *slider=DTGTK_SLIDER(widget);
   int state = gtk_widget_get_state(widget);
   int width = widget->allocation.width;
