@@ -700,42 +700,52 @@ void dt_accel_connect_preset_lib(dt_lib_module_t *module,  const gchar *path)
 
 void dt_accel_deregister_iop(dt_iop_module_t *module,const gchar *path)
 {
-  dt_accel_t *accel;
   GSList *l = module->accel_closures_local;
   char build_path[1024];
   dt_accel_path_iop(build_path, 1024, module->op, path);
   while(l)
   {
-    accel = (dt_accel_t*)l->data;
-    if(!strcmp(accel->path,build_path)) {
+    dt_accel_t *accel = (dt_accel_t*)l->data;
+    if(!strncmp(accel->path, build_path, 1024))
+    {
       module->accel_closures_local = g_slist_delete_link(module->accel_closures_local, l);
       l = NULL;
+      free(accel);
+    }
+    else
+    {
+      l = g_slist_next(l);
     }
   }
   l = darktable.control->accelerator_list;
   while(l)
   {
     dt_accel_t *accel = (dt_accel_t*)l->data;
-    if(!strcmp(accel->path, build_path))
+    if(!strncmp(accel->path, build_path, 1024))
     {
       darktable.control->accelerator_list = g_slist_delete_link(darktable.control->accelerator_list, l);
       l = NULL;
-    } else {
+      free(accel);
+    }
+    else
+    {
       l = g_slist_next(l);
     }
   }
   l = module->accel_closures;
   while(l)
   {
-    accel = (dt_accel_t*)l->data;
-    if(!strcmp(accel->path, build_path))
+    dt_accel_t *accel = (dt_accel_t*)l->data;
+    if(!strncmp(accel->path, build_path, 1024))
     {
       if(!accel->local || !module->local_closures_connected)
         gtk_accel_group_disconnect(darktable.control->accelerators, accel->closure);
       module->accel_closures = g_slist_delete_link(module->accel_closures, l);
       l = NULL;
       free(accel);
-    } else {
+    }
+    else
+    {
       l = g_slist_next(l);
     }
   }
@@ -751,7 +761,7 @@ void dt_accel_deregister_lib(dt_lib_module_t *module,const gchar *path)
   while(l)
   {
     dt_accel_t *accel = (dt_accel_t*)l->data;
-    if(!strcmp(accel->path, build_path))
+    if(!strncmp(accel->path, build_path, 1024))
     {
       darktable.control->accelerator_list = g_slist_delete_link(darktable.control->accelerator_list, l);
       l = NULL;
@@ -763,7 +773,7 @@ void dt_accel_deregister_lib(dt_lib_module_t *module,const gchar *path)
   while(l)
   {
     accel = (dt_accel_t*)l->data;
-    if(!strcmp(accel->path, build_path))
+    if(!strncmp(accel->path, build_path, 1024))
     {
       module->accel_closures = g_slist_delete_link(module->accel_closures, l);
       gtk_accel_group_disconnect(darktable.control->accelerators, accel->closure);
@@ -784,7 +794,7 @@ void dt_accel_deregister_global(const gchar *path)
   while(l)
   {
     dt_accel_t *accel = (dt_accel_t*)l->data;
-    if(!strcmp(accel->path, build_path))
+    if(!strncmp(accel->path, build_path, 1024))
     {
       darktable.control->accelerator_list = g_slist_delete_link(darktable.control->accelerator_list, l);
       gtk_accel_group_disconnect(darktable.control->accelerators, accel->closure);
@@ -810,7 +820,7 @@ void dt_accel_rename_preset_iop(dt_iop_module_t *module,const gchar *path,const
   while(l)
   {
     accel = (dt_accel_t*)l->data;
-    if(!strcmp(accel->path, build_path))
+    if(!strncmp(accel->path, build_path, 1024))
     {
       GtkAccelKey tmp_key = *(gtk_accel_group_find(darktable.control->accelerators,find_accel_internal,accel->closure));
       gboolean local = accel->local;
@@ -834,7 +844,7 @@ void dt_accel_rename_preset_lib(dt_lib_module_t *module,const gchar *path,const
   while(l)
   {
     accel = (dt_accel_t*)l->data;
-    if(!strcmp(accel->path, build_path))
+    if(!strncmp(accel->path, build_path, 1024))
     {
       GtkAccelKey tmp_key = *(gtk_accel_group_find(darktable.control->accelerators,find_accel_internal,accel->closure));
       dt_accel_deregister_lib(module,path);
@@ -857,7 +867,7 @@ void dt_accel_rename_global(const gchar *path,const gchar *new_path)
   while(l)
   {
     accel = (dt_accel_t*)l->data;
-    if(!strcmp(accel->path, build_path))
+    if(!strncmp(accel->path, build_path, 1024))
     {
       GtkAccelKey tmp_key = *(gtk_accel_group_find(darktable.control->accelerators,find_accel_internal,accel->closure));
       dt_accel_deregister_global(path);
