@@ -16,9 +16,7 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#define _XOPEN_SOURCE // for strptime
-
-#include <time.h>
+#include "common/darktable.h"
 #include "develop/develop.h"
 #include "control/control.h"
 #include "control/jobs.h"
@@ -31,6 +29,8 @@
 #include "dtgtk/label.h"
 #include "gui/camera_import_dialog.h"
 
+#include <time.h>
+
 /*
 
   g_object_ref(model); // Make sure the model stays with us after the tree view unrefs it
@@ -437,7 +437,7 @@ int _camera_storage_image_filename(const dt_camera_t *camera,const char *filenam
     return 0;
 
 
-  gdk_threads_enter();
+  gboolean i_own_lock = dt_control_gdk_lock();
   char exif_info[1024]= {0};
   char file_info[4096]= {0};
 
@@ -487,7 +487,8 @@ int _camera_storage_image_filename(const dt_camera_t *camera,const char *filenam
   if(pixbuf) g_object_unref(pixbuf);
   if(thumb) g_object_ref(thumb);
 
-  gdk_threads_leave();
+  if (i_own_lock) dt_control_gdk_unlock();
+
   return 1;
 }
 
