@@ -18,15 +18,6 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-#include <stdlib.h>
-#include <math.h>
-#include <string.h>
-#include <strings.h>
-#include <gtk/gtk.h>
-#include <inttypes.h>
-#ifdef HAVE_GEGL
-#include <gegl.h>
-#endif
 #include "common/colorspaces.h"
 #include "develop/develop.h"
 #include "develop/imageop.h"
@@ -36,6 +27,12 @@
 #include "gui/gtk.h"
 #include "dtgtk/button.h"
 
+#include <stdlib.h>
+#include <math.h>
+#include <string.h>
+#include <strings.h>
+#include <gtk/gtk.h>
+#include <inttypes.h>
 
 /**
  * color transfer somewhat based on the glorious paper `color transfer between images'
@@ -413,7 +410,7 @@ spinbutton_changed (GtkSpinButton *button, dt_iop_module_t *self)
   memset(p->mean,0, sizeof(float)*MAXN*2);
   memset(p->var,0,  sizeof(float)*MAXN*2);
   //gtk_widget_set_size_request(g->area, 300, MIN(100, 300/p->n));
-  dt_control_queue_draw(self->widget);
+  dt_control_queue_redraw_widget(self->widget);
 }
 
 static void
@@ -425,6 +422,7 @@ acquire_button_pressed (GtkButton *button, dt_iop_module_t *self)
   self->request_color_pick = 1;
   self->color_picker_box[0] = self->color_picker_box[1] = 0.0f;
   self->color_picker_box[2] = self->color_picker_box[3] = 1.0f;
+  self->color_picker_point[0] = self->color_picker_point[1] = 0.5f;
   dt_iop_colortransfer_params_t *p = (dt_iop_colortransfer_params_t *)self->params;
   p->flag = ACQUIRE;
   if(self->off) gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self->off), 1);
@@ -493,7 +491,7 @@ void commit_params (struct dt_iop_module_t *self, dt_iop_params_t *p1, dt_dev_pi
         if(fwrite(&g->flowback, self->params_size, 1, f) > 0) g->flowback.flag = APPLY;
         fclose(f);
       }
-      dt_control_queue_draw(self->widget);
+      dt_control_queue_redraw_widget(self->widget);
     }
   }
   else
@@ -541,7 +539,7 @@ void gui_update(struct dt_iop_module_t *self)
   gtk_spin_button_set_value(g->spinbutton, p->n);
   //gtk_widget_set_size_request(g->area, 300, MIN(100, 300/p->n));
   // redraw color cluster preview
-  dt_control_queue_draw(self->widget);
+  dt_control_queue_redraw_widget(self->widget);
 }
 
 void init(dt_iop_module_t *module)
@@ -550,7 +548,7 @@ void init(dt_iop_module_t *module)
   module->params = malloc(sizeof(dt_iop_colortransfer_params_t));
   module->default_params = malloc(sizeof(dt_iop_colortransfer_params_t));
   module->default_enabled = 0;
-  module->priority = 413; // module order created by iop_dependencies.py, do not edit!
+  module->priority = 431; // module order created by iop_dependencies.py, do not edit!
   module->params_size = sizeof(dt_iop_colortransfer_params_t);
   module->gui_data = NULL;
   dt_iop_colortransfer_params_t tmp;
