@@ -334,8 +334,8 @@ process_cl (struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, cl_mem
   err = dt_opencl_enqueue_copy_buffer_to_image(devid, dev_temp2, dev_out, 0, origin, region);
   if(err != CL_SUCCESS) goto error;
 
-  if (dev_temp1 != NULL) clReleaseMemObject(dev_temp1);
-  if (dev_temp2 != NULL) clReleaseMemObject(dev_temp2);
+  if (dev_temp1 != NULL) dt_opencl_release_mem_object(dev_temp1);
+  if (dev_temp2 != NULL) dt_opencl_release_mem_object(dev_temp2);
   return TRUE;
 
 error:
@@ -634,7 +634,7 @@ void init(dt_iop_module_t *module)
   module->params = malloc(sizeof(dt_iop_lowpass_params_t));
   module->default_params = malloc(sizeof(dt_iop_lowpass_params_t));
   module->default_enabled = 0;
-  module->priority = 695; // module order created by iop_dependencies.py, do not edit!
+  module->priority = 725; // module order created by iop_dependencies.py, do not edit!
   module->params_size = sizeof(dt_iop_lowpass_params_t);
   module->gui_data = NULL;
   dt_iop_lowpass_params_t tmp = (dt_iop_lowpass_params_t)
@@ -658,14 +658,14 @@ void init_global(dt_iop_module_so_t *module)
 
 void init_presets (dt_iop_module_so_t *self)
 {
-  DT_DEBUG_SQLITE3_EXEC(darktable.db, "begin", NULL, NULL, NULL);
+  DT_DEBUG_SQLITE3_EXEC(dt_database_get(darktable.db), "begin", NULL, NULL, NULL);
 
   dt_gui_presets_add_generic(_("local contrast mask"), self->op, self->version(), &(dt_iop_lowpass_params_t)
   {
     0, 50.0f, -1.0f, 0.0f
   }, sizeof(dt_iop_lowpass_params_t), 1);
 
-  DT_DEBUG_SQLITE3_EXEC(darktable.db, "commit", NULL, NULL, NULL);
+  DT_DEBUG_SQLITE3_EXEC(dt_database_get(darktable.db), "commit", NULL, NULL, NULL);
 }
 
 void cleanup(dt_iop_module_t *module)
