@@ -27,6 +27,7 @@
 #include "common/metadata.h"
 #include "common/utility.h"
 #include "libs/collect.h"
+#include "views/view.h"
 
 DT_MODULE(1)
 
@@ -69,12 +70,13 @@ typedef enum dt_lib_collect_cols_t
   DT_LIB_COLLECT_COL_TEXT=0,
   DT_LIB_COLLECT_COL_ID,
   DT_LIB_COLLECT_COL_TOOLTIP,
+  DT_LIB_COLLECT_COL_PATH,
   DT_LIB_COLLECT_NUM_COLS
 }
 dt_lib_collect_cols_t;
 
 
-static void _lib_collect_gui_update (dt_lib_collect_t *d);
+static void _lib_collect_gui_update (dt_lib_module_t *d);
 
 
 const char*
@@ -134,7 +136,7 @@ void *get_params(dt_lib_module_t *self, int *size)
 
 int set_params(dt_lib_module_t *self, const void *params, int size)
 {
-  /* update gconf settings from params */
+  /* update conf settings from params */
   dt_lib_collect_params_t *p = (dt_lib_collect_params_t *)params;
   char confname[200];
   
@@ -157,7 +159,7 @@ int set_params(dt_lib_module_t *self, const void *params, int size)
   dt_conf_set_int(confname, p->rules);
   
   /* update ui */
-  _lib_collect_gui_update((dt_lib_collect_t*)self->data);
+  _lib_collect_gui_update(self);
 
   /* update view */
   dt_collection_update_query(darktable.collection);
@@ -166,10 +168,14 @@ int set_params(dt_lib_module_t *self, const void *params, int size)
 }
 
 
-uint32_t
-views()
+uint32_t views()
 {
-  return DT_LIGHTTABLE_VIEW | DT_LEFT_PANEL_VIEW;
+  return DT_VIEW_LIGHTTABLE;
+}
+
+uint32_t container()
+{
+  return DT_UI_CONTAINER_PANEL_LEFT_CENTER;
 }
 
 static dt_lib_collect_t*
@@ -180,7 +186,7 @@ get_collect (dt_lib_collect_rule_t *r)
 }
 
 static gboolean
-entry_key_press (GtkEntry *entry, GdkEventKey *event, dt_lib_collect_rule_t *dr)
+changed_callback (GtkEntry *entry, dt_lib_collect_rule_t *dr)
 {
   // update related list
   dt_lib_collect_t *d = get_collect(dr);
@@ -204,10 +210,10 @@ entry_key_press (GtkEntry *entry, GdkEventKey *event, dt_lib_collect_rule_t *dr)
   switch(property)
   {
     case 0: // film roll
-      snprintf(query, 1024, "select distinct folder, id from film_rolls where folder like '%%%s%%'", escaped_text);
+      snprintf(query, 1024, "select distinct folder, id from film_rolls where folder like '%%%s%%'  order by id", escaped_text);
       break;
     case 1: // camera
-      snprintf(query, 1024, "select distinct maker || ' ' || model, 1 from images where maker || ' ' || model like '%%%s%%'", escaped_text);
+      snprintf(query, 1024, "select distinct maker || ' ' || model as model, 1 from images where maker || ' ' || model like '%%%s%%' order by model", escaped_text);
       break;
     case 2: // tag
       snprintf(query, 1024, "select distinct name, id from tags where name like '%%%s%%'", escaped_text);
@@ -265,32 +271,44 @@ entry_key_press (GtkEntry *entry, GdkEventKey *event, dt_lib_collect_rule_t *dr)
       // TODO: Add empty string for metadata?
       // TODO: Autogenerate this code?
     case 6: // title
-      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%'",
+      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%' order by value",
                DT_METADATA_XMP_DC_TITLE, escaped_text);
       break;
     case 7: // description
-      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%'",
+      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%' order by value",
                DT_METADATA_XMP_DC_DESCRIPTION, escaped_text);
       break;
     case 8: // creator
-      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%'",
+      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%' order by value",
                DT_METADATA_XMP_DC_CREATOR, escaped_text);
       break;
     case 9: // publisher
-      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%'",
+      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%' order by value",
                DT_METADATA_XMP_DC_PUBLISHER, escaped_text);
       break;
     case 10: // rights
-      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%'",
+      snprintf(query, 1024, "select distinct value, 1 from meta_data where key = %d and value like '%%%s%%'order by value ",
                DT_METADATA_XMP_DC_RIGHTS, escaped_text);
       break;
+    case 11: // lens
+      snprintf(query, 1024, "select distinct lens, 1 from images where lens like '%%%s%%' order by lens", escaped_text);
+      break;
+    case 12: // iso
+      snprintf(query, 1024, "select distinct cast(iso as integer) as iso, 1 from images where iso like '%%%s%%' order by iso", escaped_text);
+      break;
+    case 13: // aperature
+      snprintf(query, 1024, "select distinct round(aperture,1) as aperture, 1 from images where aperture like '%%%s%%' order by aperture", escaped_text);
+      break;
+    case 14: // filename
+      snprintf(query, 1024, "select distinct filename, 1 from images where filename like '%%%s%%' order by filename", escaped_text);
+      break;
 
     default: // case 3: // day
-      snprintf(query, 1024, "select distinct datetime_taken, 1 from images where datetime_taken like '%%%s%%'", escaped_text);
+      snprintf(query, 1024, "select distinct datetime_taken, 1 from images where datetime_taken like '%%%s%%' order by datetime_taken", escaped_text);
       break;
   }
   g_free(escaped_text);
-  DT_DEBUG_SQLITE3_PREPARE_V2(darktable.db, query, -1, &stmt, NULL);
+  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query, -1, &stmt, NULL);
   while(sqlite3_step(stmt) == SQLITE_ROW)
   {
     gtk_list_store_append(GTK_LIST_STORE(model), &iter);
@@ -299,10 +317,13 @@ entry_key_press (GtkEntry *entry, GdkEventKey *event, dt_lib_collect_rule_t *dr)
     {
       folder = dt_image_film_roll_name(folder);
     }
+    gchar *value =  (gchar *)sqlite3_column_text(stmt, 0);
+    gchar *escaped_text = g_markup_escape_text(value, strlen(value));
     gtk_list_store_set (GTK_LIST_STORE(model), &iter,
                         DT_LIB_COLLECT_COL_TEXT, folder,
                         DT_LIB_COLLECT_COL_ID, sqlite3_column_int(stmt, 1),
-                        DT_LIB_COLLECT_COL_TOOLTIP, sqlite3_column_text(stmt, 0),
+                        DT_LIB_COLLECT_COL_TOOLTIP, escaped_text,
+                        DT_LIB_COLLECT_COL_PATH, value,
                         -1);
   }
   sqlite3_finalize(stmt);
@@ -314,8 +335,10 @@ entry_key_press_exit:
 }
 
 static void
-_lib_collect_gui_update (dt_lib_collect_t *d)
+_lib_collect_gui_update (dt_lib_module_t *self)
 {
+  dt_lib_collect_t *d = (dt_lib_collect_t *)self->data;
+
   const int old = darktable.gui->reset;
   darktable.gui->reset = 1;
   const int active = CLAMP(dt_conf_get_int("plugins/lighttable/collect/num_rules") - 1, 0, (MAX_RULES-1));
@@ -363,7 +386,7 @@ _lib_collect_gui_update (dt_lib_collect_t *d)
     }
   }
   // update list of proposals
-  entry_key_press (NULL, NULL, d->rule + d->active_rule);
+  changed_callback(NULL, d->rule + d->active_rule);
   darktable.gui->reset = old;
 }
 
@@ -383,7 +406,7 @@ combo_changed (GtkComboBox *combo, dt_lib_collect_rule_t *d)
   gtk_entry_set_text(GTK_ENTRY(d->text), "");
   dt_lib_collect_t *c = get_collect(d);
   c->active_rule = d->num;
-  entry_key_press (NULL, NULL, d);
+  changed_callback(NULL, d);
   dt_collection_update_query(darktable.collection);
 }
 
@@ -398,19 +421,20 @@ row_activated (GtkTreeView *view, GtkTreePath *path, GtkTreeViewColumn *col, dt_
   const int active = d->active_rule;
   const int item = gtk_combo_box_get_active(GTK_COMBO_BOX(d->rule[active].combo));
   if(item == 0) // get full path for film rolls:
-    gtk_tree_model_get (model, &iter, DT_LIB_COLLECT_COL_TOOLTIP, &text, -1);
+    gtk_tree_model_get (model, &iter, DT_LIB_COLLECT_COL_PATH, &text, -1);
   else
     gtk_tree_model_get (model, &iter, DT_LIB_COLLECT_COL_TEXT, &text, -1);
   gtk_entry_set_text(GTK_ENTRY(d->rule[active].text), text);
   g_free(text);
-  entry_key_press (NULL, NULL, d->rule + active);
+  changed_callback(NULL, d->rule + active);
   dt_collection_update_query(darktable.collection);
+  dt_control_queue_redraw_center();
 }
 
 static void
 entry_activated (GtkWidget *entry, dt_lib_collect_rule_t *d)
 {
-  entry_key_press (NULL, NULL, d);
+  changed_callback(NULL, d);
   dt_lib_collect_t *c = get_collect(d);
   GtkTreeView *view = c->view;
   GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
@@ -423,12 +447,12 @@ entry_activated (GtkWidget *entry, dt_lib_collect_rule_t *d)
       gchar *text;
       const int item = gtk_combo_box_get_active(GTK_COMBO_BOX(d->combo));
       if(item == 0) // get full path for film rolls:
-        gtk_tree_model_get (model, &iter, DT_LIB_COLLECT_COL_TOOLTIP, &text, -1);
+        gtk_tree_model_get (model, &iter, DT_LIB_COLLECT_COL_PATH, &text, -1);
       else
         gtk_tree_model_get (model, &iter, DT_LIB_COLLECT_COL_TEXT, &text, -1);
       gtk_entry_set_text(GTK_ENTRY(d->text), text);
       g_free(text);
-      entry_key_press (NULL, NULL, d);
+      changed_callback(NULL, d);
     }
   }
   dt_collection_update_query(darktable.collection);
@@ -445,7 +469,7 @@ entry_focus_in_callback (GtkWidget *w, GdkEventFocus *event, dt_lib_collect_rule
 {
   dt_lib_collect_t *c = get_collect(d);
   c->active_rule = d->num;
-  entry_key_press (NULL, NULL, c->rule + c->active_rule);
+  changed_callback(NULL, c->rule + c->active_rule);
 }
 
 #if 0
@@ -569,9 +593,9 @@ menuitem_change_and_not (GtkMenuItem *menuitem, dt_lib_collect_rule_t *d)
 }
 
 static void
-collection_updated(void *d)
+collection_updated(gpointer instance,gpointer self)
 {
-  _lib_collect_gui_update((dt_lib_collect_t *)d);
+  _lib_collect_gui_update((dt_lib_module_t *)self);
 }
 
 
@@ -668,12 +692,17 @@ void
 gui_init (dt_lib_module_t *self)
 {
   dt_lib_collect_t *d = (dt_lib_collect_t *)malloc(sizeof(dt_lib_collect_t));
-  dt_collection_listener_register(collection_updated, d);
+
   self->data = (void *)d;
   self->widget = gtk_vbox_new(FALSE, 5);
   gtk_widget_set_size_request(self->widget, 100, -1);
   d->active_rule = 0;
   d->params = (dt_lib_collect_params_t*)malloc(sizeof(dt_lib_collect_params_t));
+
+  dt_control_signal_connect(darktable.signals, 
+			    DT_SIGNAL_COLLECTION_CHANGED,
+			    G_CALLBACK(collection_updated),
+			    self);
   
   GtkBox *box;
   GtkWidget *w;
@@ -703,7 +732,7 @@ gui_init (dt_lib_module_t *self)
     /* xgettext:no-c-format */
     g_object_set(G_OBJECT(w), "tooltip-text", _("type your query, use `%' as wildcard"), (char *)NULL);
     gtk_widget_add_events(w, GDK_KEY_PRESS_MASK);
-    g_signal_connect(G_OBJECT(w), "key-press-event", G_CALLBACK(entry_key_press), d->rule + i);
+    g_signal_connect(G_OBJECT(w), "changed", G_CALLBACK(changed_callback), d->rule + i);
     g_signal_connect(G_OBJECT(w), "activate", G_CALLBACK(entry_activated), d->rule + i);
     gtk_box_pack_start(box, w, TRUE, TRUE, 0);
     w = dtgtk_button_new(dtgtk_cairo_paint_presets, CPF_STYLE_FLAT|CPF_DO_NOT_USE_BORDER);
@@ -719,7 +748,7 @@ gui_init (dt_lib_module_t *self)
   gtk_container_add(GTK_CONTAINER(sw), GTK_WIDGET(view));
   gtk_box_pack_start(GTK_BOX(self->widget), GTK_WIDGET(sw), TRUE, TRUE, 0);
   gtk_tree_view_set_headers_visible(view, FALSE);
-  liststore = gtk_list_store_new(DT_LIB_COLLECT_NUM_COLS, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING);
+  liststore = gtk_list_store_new(DT_LIB_COLLECT_NUM_COLS, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_STRING);
   GtkTreeViewColumn *col = gtk_tree_view_column_new();
   gtk_tree_view_append_column(view, col);
   gtk_widget_set_size_request(GTK_WIDGET(view), -1, 300);
@@ -730,13 +759,18 @@ gui_init (dt_lib_module_t *self)
   gtk_tree_view_set_model(view, GTK_TREE_MODEL(liststore));
   g_signal_connect(G_OBJECT (view), "row-activated", G_CALLBACK (row_activated), d);
 
-  _lib_collect_gui_update(d);
+  /* setup proxy */
+  darktable.view_manager->proxy.module_collect.module = self;
+  darktable.view_manager->proxy.module_collect.update = _lib_collect_gui_update;
+
+  _lib_collect_gui_update(self);
 }
 
 void
 gui_cleanup (dt_lib_module_t *self)
 {
-  dt_collection_listener_unregister(collection_updated);
+  dt_control_signal_disconnect(darktable.signals, G_CALLBACK(collection_updated), self);
+  darktable.view_manager->proxy.module_collect.module = NULL;
   free(((dt_lib_collect_t*)self->data)->params);
   free(self->data);
   self->data = NULL;
