@@ -28,13 +28,13 @@
 #include "dtgtk/button.h"
 #include "gui/accelerators.h"
 #include "gui/gtk.h"
+#ifdef HAVE_GPHOTO2
 #include "gui/camera_import_dialog.h"
+#endif
 #include "libs/lib.h"
 
 DT_MODULE(1)
 
-// #ifdef HAVE_GPHOTO2
-
 
 #ifdef HAVE_GPHOTO2
 /** helper function to update ui with available cameras and ther actionbuttons */
@@ -44,7 +44,9 @@ static void _lib_import_ui_devices_update(dt_lib_module_t *self);
 
 typedef struct dt_lib_import_t
 {
+#ifdef HAVE_GPHOTO2
   dt_camctl_listener_t camctl_listener;
+#endif
   GtkButton *import_file;
   GtkButton *import_directory;
   GtkButton *import_camera;
@@ -336,6 +338,10 @@ static void _lib_import_single_image_callback(GtkWidget *widget,gpointer user_da
     GSList *it = list;
     int id = 0;
     int filmid = 0;
+
+    /* reset filter to display all images, otherwise view may remain empty */
+    dt_view_filter_reset_to_show_all(darktable.view_manager);
+
     while(it)
     {
       filename = (char *)it->data;
@@ -418,6 +424,9 @@ static void _lib_import_folder_callback(GtkWidget *widget,gpointer user_data)
     GSList *list = gtk_file_chooser_get_filenames (GTK_FILE_CHOOSER (filechooser));
     GSList *it = list;
 
+    /* reset filter to display all images, otherwise view may remain empty */
+    dt_view_filter_reset_to_show_all(darktable.view_manager);
+
     /* for each selected folder add import job */
     while(it)
     {
