@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    copyright (c) 2010 tobias ellinghaus.
+    copyright (c) 2010-2011 tobias ellinghaus, Henrik Andersson.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include "common/metadata.h"
 #include "common/debug.h"
 #include "control/control.h"
+#include "control/signal.h"
 #include "control/conf.h"
 #include "libs/lib.h"
 #include "gui/accelerators.h"
@@ -53,7 +54,12 @@ const char* name()
 
 uint32_t views()
 {
-  return DT_LIGHTTABLE_VIEW|DT_CAPTURE_VIEW;
+  return DT_VIEW_LIGHTTABLE | DT_VIEW_TETHERING;
+}
+
+uint32_t container()
+{
+  return DT_UI_CONTAINER_PANEL_RIGHT_CENTER;
 }
 
 static void fill_combo_box_entry(GtkComboBoxEntry **box, uint32_t count, GList **items, gboolean *multi)
@@ -125,13 +131,13 @@ static void update(dt_lib_module_t *user_data, gboolean early_bark_out)
   // using dt_metadata_get() is not possible here. we want to do all this in a single pass, everything else takes ages.
   if(imgsel < 0)  // selected images
   {
-    DT_DEBUG_SQLITE3_PREPARE_V2(darktable.db, "select key, value from meta_data where id in (select imgid from selected_images) group by key, value order by value", -1, &stmt, NULL);
+    DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "select key, value from meta_data where id in (select imgid from selected_images) group by key, value order by value", -1, &stmt, NULL);
   }
   else     // single image under mouse cursor
   {
     char query[1024];
     snprintf(query, 1024, "select key, value from meta_data where id = %d group by key, value order by value", imgsel);
-    DT_DEBUG_SQLITE3_PREPARE_V2(darktable.db, query, -1, &stmt, NULL);
+    DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query, -1, &stmt, NULL);
   }
   while(sqlite3_step(stmt) == SQLITE_ROW)
   {
@@ -178,6 +184,7 @@ static void update(dt_lib_module_t *user_data, gboolean early_bark_out)
   g_list_free(g_list_first(rights));
 }
 
+
 static gboolean expose(GtkWidget *widget, GdkEventExpose *event, gpointer user_data)
 {
   if(!dt_control_running())
@@ -237,7 +244,7 @@ static void apply_button_clicked(GtkButton *button, gpointer user_data)
 static void enter_pressed(GtkEntry *entry, gpointer user_data)
 {
   write_metadata(user_data);
-  gtk_window_set_focus(GTK_WINDOW(darktable.gui->widgets.main_window), NULL);
+  gtk_window_set_focus(GTK_WINDOW(dt_ui_main_window(darktable.gui->ui)), NULL);
 }
 
 void gui_reset(dt_lib_module_t *self)
@@ -250,6 +257,13 @@ int position()
   return 510;
 }
 
+static void _mouse_over_image_callback(gpointer instace,gpointer user_data) 
+{
+  dt_lib_module_t *self=(dt_lib_module_t *)user_data;
+  /* lets trigger an expose for a redraw of widget */
+  gtk_widget_queue_draw(GTK_WIDGET(self->widget));
+} 
+
 void init_key_accels(dt_lib_module_t *self)
 {
   dt_accel_register_lib(self, NC_("accel", "clear"), 0, 0);
@@ -279,9 +293,8 @@ void gui_init(dt_lib_module_t *self)
   self->widget = gtk_table_new(6, 2, FALSE);
   gtk_table_set_row_spacings(GTK_TABLE(self->widget), 5);
 
-  g_signal_connect(self->widget, "expose-event", G_CALLBACK(expose), (gpointer)self);
-  darktable.gui->redraw_widgets = g_list_append(darktable.gui->redraw_widgets, self->widget);
-
+  g_signal_connect(self->widget, "expose-event", G_CALLBACK(expose), self);
+ 
   label = gtk_label_new(_("title"));
   gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
   gtk_table_attach(GTK_TABLE(self->widget), label, 0, 1, 0, 1, GTK_EXPAND|GTK_FILL, 0, 0, 0);
@@ -368,12 +381,15 @@ void gui_init(dt_lib_module_t *self)
 
   gtk_table_attach(GTK_TABLE(self->widget), GTK_WIDGET(hbox), 0, 2, 5, 6, GTK_EXPAND|GTK_FILL, 0, 0, 0);
 
-  update(self, FALSE);
+  /* lets signup for mouse over image change signals */
+  dt_control_signal_connect(darktable.signals,DT_SIGNAL_MOUSE_OVER_IMAGE_CHANGE, 
+			    G_CALLBACK(_mouse_over_image_callback), self);
+
 }
 
 void gui_cleanup(dt_lib_module_t *self)
 {
-  darktable.gui->redraw_widgets = g_list_remove(darktable.gui->redraw_widgets, self->widget);
+  dt_control_signal_disconnect(darktable.signals,G_CALLBACK(_mouse_over_image_callback),self);
   free(self->data);
   self->data = NULL;
 }
@@ -402,11 +418,6 @@ void init_presets(dt_lib_module_t *self)
   add_rights_preset(self, _("all rights reserved"), _("All rights reserved."));
 }
 
-// FIXME: Is this ever called?
-void init(dt_iop_module_t *module)
-{
-}
-
 void* get_params(dt_lib_module_t *self, int *size)
 {
   dt_lib_metadata_t *d = (dt_lib_metadata_t *)self->data;
