@@ -1,6 +1,6 @@
 /*
 		This file is part of darktable,
-		copyright (c) 2010 henrik andersson.
+		copyright (c) 2010-2011 henrik andersson.
 
 		darktable is free software: you can redistribute it and/or modify
 		it under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@ typedef struct dt_capture_t
   /** The current image activated in capture view, either latest tethered shoot
   	or manually picked from filmstrip view...
   */
-  uint32_t image_id;
+  int32_t image_id;
 
   dt_view_image_over_t image_over;
 
@@ -86,17 +86,30 @@ typedef struct dt_capture_t
 }
 dt_capture_t;
 
+/* signal handler for filmstrip image switching */
+static void _view_capture_filmstrip_activate_callback(gpointer instance,gpointer user_data);
+
+static const gchar *_capture_view_get_session_filename(const dt_view_t *view,const char *filename);
+static const gchar *_capture_view_get_session_path(const dt_view_t *view);
+static uint32_t _capture_view_get_film_id(const dt_view_t *view);
+static void _capture_view_set_jobcode(const dt_view_t *view, const char *name);
+static const char *_capture_view_get_jobcode(const dt_view_t *view);
+
 const char *name(dt_view_t *self)
 {
-  return _("capture");
+  return _("tethering");
 }
 
-static void
-film_strip_activated(const int imgid, void *data)
+uint32_t view(dt_view_t *self)
 {
-  dt_view_film_strip_set_active_image(darktable.view_manager,imgid);
-  dt_control_queue_draw_all();
-  dt_view_film_strip_prefetch();
+  return DT_VIEW_TETHERING;
+}
+
+static void _view_capture_filmstrip_activate_callback(gpointer instance,gpointer user_data)
+{
+  int32_t imgid = -1;
+  if ((imgid=dt_view_filmstrip_get_activated_imgid(darktable.view_manager)) >= 0)
+    dt_control_queue_redraw_center();
 }
 
 void capture_view_switch_key_accel(void *p)
@@ -110,15 +123,18 @@ void capture_view_switch_key_accel(void *p)
     dt_ctl_switch_mode_to( DT_CAPTURE );
 }
 
-void film_strip_key_accel(GtkAccelGroup *accel_group,
+gboolean film_strip_key_accel(GtkAccelGroup *accel_group,
                           GObject *acceleratable,
                           guint keyval, GdkModifierType modifier,
                           gpointer data)
 {
-  dt_view_film_strip_toggle(darktable.view_manager, film_strip_activated, data);
-  dt_control_queue_draw_all();
+  dt_lib_module_t *m = darktable.view_manager->proxy.filmstrip.module; 
+  gboolean vs = dt_lib_is_visible(m);
+  dt_lib_set_visible(m,!vs);
+  return TRUE;
 }
 
+
 void init(dt_view_t *self)
 {
   self->data = malloc(sizeof(dt_capture_t));
@@ -135,6 +151,18 @@ void init(dt_view_t *self)
   lib->subdirectory = dt_conf_get_string("plugins/capture/storage/subpath");
   lib->filenamepattern = dt_conf_get_string("plugins/capture/storage/namepattern");
 
+  // prefetch next few from first selected image on.
+  dt_view_filmstrip_prefetch();
+
+
+  /* setup the tethering view proxy */
+  darktable.view_manager->proxy.tethering.view = self;
+  darktable.view_manager->proxy.tethering.get_film_id = _capture_view_get_film_id;
+  darktable.view_manager->proxy.tethering.get_session_filename = _capture_view_get_session_filename;
+  darktable.view_manager->proxy.tethering.get_session_path = _capture_view_get_session_path;
+  darktable.view_manager->proxy.tethering.get_job_code = _capture_view_get_jobcode;
+  darktable.view_manager->proxy.tethering.set_job_code = _capture_view_set_jobcode;
+
 }
 
 void cleanup(dt_view_t *self)
@@ -142,7 +170,8 @@ void cleanup(dt_view_t *self)
   free(self->data);
 }
 
-uint32_t dt_capture_view_get_film_id(const dt_view_t *view)
+
+uint32_t _capture_view_get_film_id(const dt_view_t *view)
 {
   g_assert( view != NULL );
   dt_capture_t *cv=(dt_capture_t *)view->data;
@@ -153,14 +182,15 @@ uint32_t dt_capture_view_get_film_id(const dt_view_t *view)
   return 1;
 }
 
-const gchar *dt_capture_view_get_session_path(const dt_view_t *view)
+
+const gchar *_capture_view_get_session_path(const dt_view_t *view)
 {
   g_assert( view != NULL );
   dt_capture_t *cv=(dt_capture_t *)view->data;
   return cv->film->dirname;
 }
 
-const gchar *dt_capture_view_get_session_filename(const dt_view_t *view,const char *filename)
+const gchar *_capture_view_get_session_filename(const dt_view_t *view,const char *filename)
 {
   g_assert( view != NULL );
   dt_capture_t *cv=(dt_capture_t *)view->data;
@@ -169,31 +199,36 @@ const gchar *dt_capture_view_get_session_filename(const dt_view_t *view,const ch
 
   gchar* fixed_path=dt_util_fix_path(cv->path);
   g_free(cv->path);
-  cv->path=fixed_path;
+  cv->path = fixed_path;
   dt_variables_expand( cv->vp, cv->path, FALSE );
-  const gchar *storage=dt_variables_get_result(cv->vp);
+  gchar *storage = g_strdup(dt_variables_get_result(cv->vp));
 
   dt_variables_expand( cv->vp, cv->filenamepattern, TRUE );
-  const gchar *file = dt_variables_get_result(cv->vp);
+  gchar *file = g_strdup(dt_variables_get_result(cv->vp));
 
   // Start check if file exist if it does, increase sequence and check again til we know that file doesnt exists..
-  gchar *fullfile=g_build_path(G_DIR_SEPARATOR_S,storage,file,(char *)NULL);
+  gchar *fullfile = g_build_path(G_DIR_SEPARATOR_S,storage,file,(char *)NULL);
+  
   if( g_file_test(fullfile, G_FILE_TEST_EXISTS) == TRUE )
   {
     do
     {
       g_free(fullfile);
+      g_free(file);
       dt_variables_expand( cv->vp, cv->filenamepattern, TRUE );
-      file = dt_variables_get_result(cv->vp);
+      file = g_strdup(dt_variables_get_result(cv->vp));
       fullfile=g_build_path(G_DIR_SEPARATOR_S,storage,file,(char *)NULL);
     }
     while( g_file_test(fullfile, G_FILE_TEST_EXISTS) == TRUE);
   }
 
+  g_free(fullfile);
+  g_free(storage);
+
   return file;
 }
 
-void dt_capture_view_set_jobcode(const dt_view_t *view, const char *name)
+void _capture_view_set_jobcode(const dt_view_t *view, const char *name)
 {
   g_assert( view != NULL );
   dt_capture_t *cv=(dt_capture_t *)view->data;
@@ -269,7 +304,7 @@ void dt_capture_view_set_jobcode(const dt_view_t *view, const char *name)
 
 }
 
-const char *dt_capture_view_get_jobcode(const dt_view_t *view)
+const char *_capture_view_get_jobcode(const dt_view_t *view)
 {
   g_assert( view != NULL );
   dt_capture_t *cv=(dt_capture_t *)view->data;
@@ -282,26 +317,20 @@ void configure(dt_view_t *self, int wd, int ht)
   //dt_capture_t *lib=(dt_capture_t*)self->data;
 }
 
-#define TOP_MARGIN		20
-#define BOTTOM_MARGIN	20
+#define MARGIN	20
 void _expose_tethered_mode(dt_view_t *self, cairo_t *cr, int32_t width, int32_t height, int32_t pointerx, int32_t pointery)
 {
   dt_capture_t *lib=(dt_capture_t*)self->data;
   lib->image_over = DT_VIEW_DESERT;
-  lib->image_id=dt_view_film_strip_get_active_image(darktable.view_manager);
+  lib->image_id = dt_view_filmstrip_get_activated_imgid(darktable.view_manager);
 
   // First of all draw image if availble
   if( lib->image_id >= 0 )
   {
-    dt_image_t *image = dt_image_cache_get(lib->image_id, 'r');
-    if( image )
-    {
-      const float wd = width/1.0;
-      cairo_translate(cr,0.0f, TOP_MARGIN);
-      dt_view_image_expose(image, &(lib->image_over), lib->image_id, cr, wd, height-TOP_MARGIN-BOTTOM_MARGIN, 1, pointerx, pointery);
-      cairo_translate(cr,0.0f, -BOTTOM_MARGIN);
-      dt_image_cache_release(image, 'r');
-    }
+    cairo_translate(cr,MARGIN, MARGIN);
+    dt_view_image_expose(&(lib->image_over), lib->image_id, 
+			 cr, width-(MARGIN*2.0f), height-(MARGIN*2.0f), 1, 
+			 pointerx, pointery);
   }
 }
 
@@ -310,18 +339,21 @@ void expose(dt_view_t *self, cairo_t *cri, int32_t width_i, int32_t height_i, in
 {
   dt_capture_t *lib = (dt_capture_t *)self->data;
 
-  int32_t width  = MIN(width_i,  DT_IMAGE_WINDOW_SIZE);
-  int32_t height = MIN(height_i, DT_IMAGE_WINDOW_SIZE);
+  const int32_t capwd = darktable.thumbnail_width;
+  const int32_t capht = darktable.thumbnail_height;
+  int32_t width  = MIN(width_i,  capwd);
+  int32_t height = MIN(height_i, capht);
 
   cairo_set_source_rgb (cri, .2, .2, .2);
   cairo_rectangle(cri, 0, 0, width_i, height_i);
   cairo_fill (cri);
 
 
-  if(width_i  > DT_IMAGE_WINDOW_SIZE) cairo_translate(cri, -(DT_IMAGE_WINDOW_SIZE-width_i) *.5f, 0.0f);
-  if(height_i > DT_IMAGE_WINDOW_SIZE) cairo_translate(cri, 0.0f, -(DT_IMAGE_WINDOW_SIZE-height_i)*.5f);
+  if(width_i  > capwd) cairo_translate(cri, -(capwd-width_i) *.5f, 0.0f);
+  if(height_i > capht) cairo_translate(cri, 0.0f, -(capht-height_i)*.5f);
 
   // Mode dependent expose of center view
+  cairo_save(cri);
   switch(lib->mode)
   {
     case DT_CAPTURE_MODE_TETHERED: // tethered mode
@@ -329,6 +361,7 @@ void expose(dt_view_t *self, cairo_t *cri, int32_t width_i, int32_t height_i, in
       _expose_tethered_mode(self, cri, width, height, pointerx, pointery);
       break;
   }
+  cairo_restore(cri);
 
   // post expose to modules
   GList *modules = darktable.lib->plugins;
@@ -336,106 +369,58 @@ void expose(dt_view_t *self, cairo_t *cri, int32_t width_i, int32_t height_i, in
   while(modules)
   {
     dt_lib_module_t *module = (dt_lib_module_t *)(modules->data);
-    if( (module->views() & DT_CAPTURE_VIEW) && module->gui_post_expose )
+    if( (module->views() & self->view(self)) && module->gui_post_expose )
       module->gui_post_expose(module,cri,width,height,pointerx,pointery);
     modules = g_list_next(modules);
   }
 
 }
 
+int try_enter(dt_view_t *self)
+{
+  /* verify that camera supports tethering and is available */
+  if (dt_camctl_can_enter_tether_mode(darktable.camctl,NULL) )
+  {
+    dt_conf_set_int( "plugins/capture/mode", DT_CAPTURE_MODE_TETHERED);
+    return 0;
+  }
+
+  dt_control_log(_("no camera with tethering support available for use..."));
+
+  return 1;
+}
+
+static void _capture_mipamps_updated_signal_callback(gpointer instance, gpointer user_data)
+{
+  dt_control_queue_redraw_center();
+}
+
+
 void enter(dt_view_t *self)
 {
   dt_capture_t *lib = (dt_capture_t *)self->data;
 
   lib->mode = dt_conf_get_int("plugins/capture/mode");
 
+  /* connect signal for mipmap update for a redraw */
+  dt_control_signal_connect(darktable.signals, DT_SIGNAL_DEVELOP_MIPMAP_UPDATED,
+			    G_CALLBACK(_capture_mipamps_updated_signal_callback), 
+          (gpointer)self);
 
-  // add expanders
-  GtkBox *box = GTK_BOX(darktable.gui->widgets.plugins_vbox);
 
-  // adjust gui:
-  GtkWidget *widget;
-  widget = darktable.gui->widgets.histogram_expander;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.import_eventbox;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.top;
-  gtk_widget_set_visible(widget, TRUE);
-  widget = darktable.gui->widgets.bottom_darkroom_box;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.bottom_lighttable_box;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.plugins_vbox_left;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.module_list_eventbox;
-  gtk_widget_set_visible(widget, FALSE);
+  /* connect signal for fimlstrip image activate */
+  dt_control_signal_connect(darktable.signals, 
+			    DT_SIGNAL_VIEWMANAGER_FILMSTRIP_ACTIVATE,
+			    G_CALLBACK(_view_capture_filmstrip_activate_callback),
+			    self);
 
-  gtk_widget_set_visible(darktable.gui->
-                         widgets.modulegroups_eventbox, FALSE);
+  dt_view_filmstrip_scroll_to_image(darktable.view_manager, lib->image_id, TRUE);
 
-  GList *modules = g_list_last(darktable.lib->plugins);
-  while(modules!=darktable.lib->plugins)
-  {
-    dt_lib_module_t *module = (dt_lib_module_t *)(modules->data);
-    if( module->views() & DT_CAPTURE_VIEW )
-    {
-      // Module does support this view let's add it to plugin box
-      // soo here goes the special cases for capture view
-      if( !( strcmp(module->name(),"tethered shoot")==0 && lib->mode != DT_CAPTURE_MODE_TETHERED ) )
-      {
-        module->gui_init(module);
-        module->accel_closures = NULL;
-        if(module->connect_key_accels)
-          module->connect_key_accels(module);
-        // add the widget created by gui_init to an expander and both to list.
-        GtkWidget *expander = dt_lib_gui_get_expander(module);
-        gtk_box_pack_start(box, expander, FALSE, FALSE, 0);
-        dt_lib_connect_common_accels(module);
-      }
-    }
-    modules = g_list_previous(modules);
-  }
-
-  // end marker widget:
-  GtkWidget *endmarker = gtk_drawing_area_new();
-  gtk_box_pack_start(box, endmarker, FALSE, FALSE, 0);
-  g_signal_connect (G_OBJECT (endmarker), "expose-event",
-                    G_CALLBACK (dt_control_expose_endmarker), 0);
-  gtk_widget_set_size_request(endmarker, -1, 50);
-
-  gtk_widget_show_all(GTK_WIDGET(box));
-  // close expanders
-  modules = darktable.lib->plugins;
-  while(modules)
-  {
-    dt_lib_module_t *module = (dt_lib_module_t *)(modules->data);
-    if( module->views() & DT_CAPTURE_VIEW )
-    {
-      char var[1024];
-      snprintf(var, 1024, "plugins/capture/%s/expanded", module->plugin_name);
-      gboolean expanded = dt_conf_get_bool(var);
-      gtk_expander_set_expanded (module->expander, expanded);
-      if(expanded) gtk_widget_show_all(module->widget);
-      else         gtk_widget_hide_all(module->widget);
-      module->accel_closures = NULL;
-      if(module->connect_key_accels)
-        module->connect_key_accels(module);
-    }
-    modules = g_list_next(modules);
-  }
-
-  // Check if we should enable view of the filmstrip
-  if(dt_conf_get_bool("plugins/filmstrip/on"))
-  {
-    dt_view_film_strip_scroll_to(darktable.view_manager, lib->image_id);
-    dt_view_film_strip_open(darktable.view_manager, film_strip_activated, self);
-    dt_view_film_strip_prefetch();
-  }
 
   // initialize a default session...
   char* tmp = dt_conf_get_string("plugins/capture/jobcode");
-  dt_capture_view_set_jobcode(self, tmp);
-  free(tmp);
+  _capture_view_set_jobcode(self, tmp);
+  g_free(tmp);
 }
 
 void dt_lib_remove_child(GtkWidget *widget, gpointer data)
@@ -446,46 +431,14 @@ void dt_lib_remove_child(GtkWidget *widget, gpointer data)
 void leave(dt_view_t *self)
 {
   dt_capture_t *cv = (dt_capture_t *)self->data;
-  if(dt_conf_get_bool("plugins/filmstrip/on"))
-    dt_view_film_strip_close(darktable.view_manager);
 
   if( dt_film_is_empty(cv->film->id) != 0)
     dt_film_remove(cv->film->id );
 
-  // Restore user interface
-  GtkWidget *widget;
-  widget = darktable.gui->widgets.import_eventbox;
-  gtk_widget_set_visible(widget, TRUE);
-  widget = darktable.gui->widgets.navigation_expander;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.histogram_expander;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.snapshots_eventbox;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.history_eventbox;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.bottom_darkroom_box;
-  gtk_widget_set_visible(widget, FALSE);
-  widget = darktable.gui->widgets.bottom_lighttable_box;
-  gtk_widget_set_visible(widget, TRUE);
-  widget = darktable.gui->widgets.plugins_vbox_left;
-  gtk_widget_set_visible(widget, TRUE);
-  widget = darktable.gui->widgets.module_list_eventbox;
-  gtk_widget_set_visible(widget, FALSE);
-
-  // cleanup the DT_CAPTURE_VIEW modules
-  GList *it = darktable.lib->plugins;
-  while(it)
-  {
-    dt_lib_module_t *module = (dt_lib_module_t *)(it->data);
-    if( (module->views() & DT_CAPTURE_VIEW) )
-      module->gui_cleanup(module);
-    dt_accel_disconnect_list(module->accel_closures);
-    it = g_list_next(it);
-  }
-  GtkBox *box = GTK_BOX(darktable.gui->widgets.plugins_vbox);
-  gtk_container_foreach(GTK_CONTAINER(box), (GtkCallback)dt_lib_remove_child, (gpointer)box);
-
+  /* disconnect from filmstrip image activate */
+  dt_control_signal_disconnect(darktable.signals,
+			       G_CALLBACK(_view_capture_filmstrip_activate_callback),
+			       (gpointer)self);
 }
 
 void reset(dt_view_t *self)
@@ -495,119 +448,9 @@ void reset(dt_view_t *self)
   //DT_CTL_SET_GLOBAL(lib_image_mouse_over_id, -1);
 }
 
-
-void mouse_leave(dt_view_t *self)
-{
-  /*dt_library_t *lib = (dt_library_t *)self->data;
-  if(!lib->pan && dt_conf_get_int("plugins/lighttable/images_in_row") != 1)
-  {
-  	DT_CTL_SET_GLOBAL(lib_image_mouse_over_id, -1);
-  	dt_control_queue_draw_all(); // remove focus
-  }*/
-}
-
-
 void mouse_moved(dt_view_t *self, double x, double y, int which)
 {
-  // update stars/etc :(
-  //dt_control_queue_draw_all();
-}
-
-
-int button_released(dt_view_t *self, double x, double y, int which, uint32_t state)
-{
-  /*dt_library_t *lib = (dt_library_t *)self->data;
-  lib->pan = 0;
-  if(which == 1) dt_control_change_cursor(GDK_LEFT_PTR);*/
-  return 1;
-}
-
-
-int button_pressed(dt_view_t *self, double x, double y, int which, int type, uint32_t state)
-{
-  /*dt_library_t *lib = (dt_library_t *)self->data;
-  lib->modifiers = state;
-  lib->button = which;
-  lib->select_offset_x = lib->zoom_x;
-  lib->select_offset_y = lib->zoom_y;
-  lib->select_offset_x += x;
-  lib->select_offset_y += y;
-  lib->pan = 1;
-  if(which == 1) dt_control_change_cursor(GDK_HAND1);
-  if(which == 1 && type == GDK_2BUTTON_PRESS) return 0;
-  // image button pressed?
-  switch(lib->image_over)
-  {
-  	case DT_LIB_DESERT: break;
-  	case DT_LIB_STAR_1: case DT_LIB_STAR_2: case DT_LIB_STAR_3: case DT_LIB_STAR_4:
-  	{
-  		int32_t mouse_over_id;
-  		DT_CTL_GET_GLOBAL(mouse_over_id, lib_image_mouse_over_id);
-  		dt_image_t *image = dt_image_cache_get(mouse_over_id, 'r');
-  		image->dirty = 1;
-  		if(lib->image_over == DT_LIB_STAR_1 && ((image->flags & 0x7) == 1)) image->flags &= ~0x7;
-  		else
-  		{
-  			image->flags &= ~0x7;
-  			image->flags |= lib->image_over;
-  		}
-  		dt_image_cache_flush(image);
-  		dt_image_cache_release(image, 'r');
-  		break;
-  	}
-  	default:
-  		return 0;
-  }*/
-  return 1;
-}
-
-
-int key_pressed(dt_view_t *self, guint key, guint state)
-{
-  return 1;
-}
-
-void border_scrolled(dt_view_t *view, double x, double y, int which, int up)
-{
-  /*dt_library_t *lib = (dt_library_t *)view->data;
-  if(which == 0 || which == 1)
-  {
-  	if(up) lib->track = -DT_LIBRARY_MAX_ZOOM;
-  	else   lib->track =  DT_LIBRARY_MAX_ZOOM;
-  }
-  else if(which == 2 || which == 3)
-  {
-  	if(up) lib->track = -1;
-  	else   lib->track =  1;
-  }*/
-  dt_control_queue_draw_all();
-}
-
-void scrolled(dt_view_t *view, double x, double y, int up)
-{
-  /*dt_library_t *lib = (dt_library_t *)view->data;
-  GtkWidget *widget = darktable.gui->widgets.lighttable_zoom_spinbutton;
-  const int layout = dt_conf_get_int("plugins/lighttable/layout");
-  if(layout == 1)
-  {
-  	if(up) lib->track = -DT_LIBRARY_MAX_ZOOM;
-  	else   lib->track =  DT_LIBRARY_MAX_ZOOM;
-  }
-  else
-  { // zoom
-  	int zoom = dt_conf_get_int("plugins/lighttable/images_in_row");
-  	if(up)
-  	{
-  		zoom--;
-  		if(zoom < 1) zoom = 1;
-  	}
-  	else
-  	{
-  		zoom++;
-  		if(zoom > 2*DT_LIBRARY_MAX_ZOOM) zoom = 2*DT_LIBRARY_MAX_ZOOM;
-  	}
-  	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widget), zoom);
-  }*/
+  dt_control_queue_redraw_center();
 }
 
 void init_key_accels(dt_view_t *self)
@@ -623,3 +466,5 @@ void connect_key_accels(dt_view_t *self)
                                      (gpointer)self, NULL);
   dt_accel_connect_view(self, "toggle film strip", closure);
 }
+
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
